@@ -26,6 +26,9 @@ FavoriteListView::FavoriteListView( const std::string& url,
     // D&Dで編集可能
     set_editable( true );
 
+    // スレをお気に入りに追加したらしおりをつけるかどうか
+    set_bookmark( CONFIG::get_bookmark_drop() );
+
     set_open_only_onedir( CONFIG::get_open_one_favorite() );
 }
  
@@ -79,7 +82,7 @@ void FavoriteListView::show_view()
 //
 Gtk::Menu* FavoriteListView::get_popupmenu( const std::string& url )
 {
-    Gtk::Menu* popupmenu;
+    Gtk::Menu* popupmenu = NULL;
     if( url.empty() ) popupmenu = id2popupmenu(  "/popup_menu_favorite_space" );
     else{
         std::list< Gtk::TreeModel::iterator > list_it = get_treeview().get_selected_iterators();
