@@ -47,14 +47,6 @@ using namespace BOARD;
 
 
 
-// 自動ソート抑制
-// -2 = DEFAULT_UNSORTED_COLUMN_ID
-//
-// 列に値をセットする前にUNSORTED_COLUMN()しておかないと
-// いちいちソートをかけるので極端に遅くなる
-#define UNSORTED_COLUMN() do{ m_liststore->gobj()->sort_column_id = -2; } while(0)
-
-
 enum{
     DEFAULT_COLMUN_WIDTH = 50
 };
@@ -63,9 +55,10 @@ enum{
 enum{
     COL_MARKVAL_OLD = -2,        // dat 落ち
     COL_MARKVAL_FINISHED = -1,   // キャッシュあり、新着無し、規定スレ数を越えている
-    COL_MARKVAL_NORMAL = 0,      // 通常状態
-    COL_MARKVAL_NEWTHREAD_HOUR,  // 新スレ( CONFIG::get_newthread_hour 時間以内 )
-    COL_MARKVAL_NEWTHREAD,       // 前回の板一覧読み込み時から新しく出来たスレ
+    COL_MARKVAL_NORMAL = 0,      // 通常状態、キャッシュ無し、
+    COL_MARKVAL_924,             // スレッド924、キャッシュ無し
+    COL_MARKVAL_NEWTHREAD_HOUR,  // 新スレ( CONFIG::get_newthread_hour 時間以内 )、キャッシュ無し
+    COL_MARKVAL_NEWTHREAD,       // 前回の板一覧読み込み時から新しく出来たスレ、キャッシュ無し
     COL_MARKVAL_CACHED,          // キャッシュあり、新着無し
     COL_MARKVAL_BROKEN_SUBJECT,  // キャッシュあり、新着無しだが subject.txt が壊れている可能性がある
     COL_MARKVAL_UPDATED,         // キャッシュあり、新着有り
@@ -90,21 +83,23 @@ enum
 };
 
 
+
+#define DELETE_COLUMN(col) do{ if( ! col ) { delete col; col = NULL; } }while(0)
+
 // set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ) を指定して append_columnする
 #define APPEND_COLUMN(col,title,model) do{                    \
-if( ! col ) delete col; \
 col = Gtk::manage( new Gtk::TreeViewColumn( title, model ) );   \
 col->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ); \
 m_treeview.append_column( *col ); \
 }while(0)
 
 
-BoardViewBase::BoardViewBase( const std::string& url )
+BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board )
     : SKELETON::View( url ),
-      m_url_board( url ),
       m_treeview( url, DNDTARGET_FAVORITE, true, CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
       m_col_mark( NULL ),
       m_col_id( NULL ),
+      m_col_board( NULL ),
       m_col_subject( NULL ),
       m_col_res( NULL ),
       m_col_str_load( NULL ),     
@@ -112,13 +107,21 @@ BoardViewBase::BoardViewBase( const std::string& url )
       m_col_since( NULL ),
       m_col_write( NULL ),
       m_col_speed( NULL ),
+      m_clicked( false ),
       m_col( COL_NUM_COL ),
       m_previous_col( COL_NUM_COL ),
       m_sortmode( SORTMODE_ASCEND ),
       m_previous_sortmode( false ),
       m_loading( false ),
-      m_enable_menuslot( true )
+      m_enable_menuslot( true ),
+      m_load_subject_txt( true ),
+      m_show_col_board( show_col_board )
 {
+    // 次スレ検索ビューのようにURLの途中に http が入っている場合は取り除く
+    const size_t pos = url.rfind( "http://" );
+    if( pos != std::string::npos && pos != 0 ) m_url_board = DBTREE::url_subject( url.substr( 0, pos ) );
+    else m_url_board = DBTREE::url_subject( url );
+
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
@@ -151,6 +154,7 @@ BoardViewBase::BoardViewBase( const std::string& url )
     // ソート関数セット
     m_liststore->set_sort_func( COL_MARK, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );    
     m_liststore->set_sort_func( COL_ID, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_BOARD, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_SUBJECT, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_RES, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_STR_LOAD, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
@@ -196,6 +200,7 @@ BoardViewBase::BoardViewBase( const std::string& url )
     action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ(_O)..." ), sigc::mem_fun( *this, &BoardViewBase::show_preference ) );
     action_group()->add( Gtk::Action::create( "SaveDat", ITEM_NAME_SAVE_DAT + std::string( "(_S)..." ) ),
                          sigc::mem_fun( *this, &BoardViewBase::slot_save_dat ) );
+    action_group()->add( Gtk::Action::create( "SearchNextArticle", "次スレ検索"), sigc::mem_fun( *this, &BoardViewBase::slot_search_next ) );
 
     ui_manager() = Gtk::UIManager::create();    
     ui_manager()->insert_action_group( action_group() );
@@ -214,8 +219,8 @@ BoardViewBase::BoardViewBase( const std::string& url )
     "<menuitem action='CopyTitleURL'/>"
     "<separator/>"
     "<menuitem action='SaveDat'/>"
-    "<separator/>"
     "<menuitem action='Favorite_Article'/>"
+    "<menuitem action='SearchNextArticle'/>"
     "<separator/>"
     "<menuitem action='AboneThread'/>"
     "<separator/>"
@@ -253,6 +258,11 @@ BoardViewBase::BoardViewBase( const std::string& url )
     "<menuitem action='Favorite_Board'/>"
     "</popup>"
 
+    // お気に入りボタン押した時のメニュー( スレのみ )
+    "<popup name='popup_menu_favorite_article'>"
+    "<menuitem action='Favorite_Article'/>"
+    "</popup>"
+
 
     // 削除ボタン押した時のメニュー
     "<popup name='popup_menu_delete'>"
@@ -284,8 +294,6 @@ BoardViewBase::~BoardViewBase()
 #ifdef _DEBUG    
     std::cout << "BoardViewBase::~BoardViewBase : " << get_url() << std::endl;
 #endif
-
-    save_column_width();
 }
 
 
@@ -295,6 +303,19 @@ SKELETON::Admin* BoardViewBase::get_admin()
 }
 
 
+//
+// url 更新
+//
+// 移転があったときなどにadminから呼び出される
+//
+void BoardViewBase::update_url( const std::string& url_old, const std::string& url_new )
+{
+    if( m_url_board.find( url_old ) == 0 ) m_url_board = url_new + m_url_board.substr( url_old.length() );
+
+    SKELETON::View::update_url( url_old, url_new );
+}
+
+
 // アイコンのID取得
 const int BoardViewBase::get_icon( const std::string& iconname )
 {
@@ -323,6 +344,28 @@ const std::string BoardViewBase::url_for_copy()
 }
 
 
+//
+// 行数
+//
+const int BoardViewBase::get_row_size()
+{
+    return m_treeview.get_row_size();
+}
+
+
+//
+// 自動ソート抑制
+// -2 = DEFAULT_UNSORTED_COLUMN_ID
+//
+// 追加や更新などで列に値をセットする前に実行してしておかないと
+// いちいちソートをかけるので極端に遅くなる
+//
+void BoardViewBase::unsorted_column()
+{
+    m_liststore->gobj()->sort_column_id = -2;
+}
+
+
 //
 // url から row を取得
 //
@@ -333,8 +376,8 @@ Gtk::TreeModel::Row BoardViewBase::get_row_from_url( const std::string& url )
     for( it = child.begin() ; it != child.end() ; ++it ){
 
         Gtk::TreeModel::Row row = *( it );
-        Glib::ustring id_dat = row[ m_columns.m_col_id_dat ];
-        if( url.find( id_dat ) != std::string::npos ) return row;
+        DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+        if( url == art->get_url() ) return row;
     }
 
     return Gtk::TreeModel::Row();
@@ -348,13 +391,39 @@ void BoardViewBase::update_columns()
 {
     m_treeview.remove_all_columns();
 
+    DELETE_COLUMN( m_col_id );
+    DELETE_COLUMN( m_col_board );
+    DELETE_COLUMN( m_col_subject );
+    DELETE_COLUMN( m_col_res );
+    DELETE_COLUMN( m_col_str_load );
+    DELETE_COLUMN( m_col_str_new );
+    DELETE_COLUMN( m_col_since );
+    DELETE_COLUMN( m_col_write );
+    DELETE_COLUMN( m_col_speed );
+
     int num = 0;
+
+    // 先頭に「板」列を追加
+    if( m_show_col_board ){
+
+        bool append_board = true;
+        for(;;){
+            const int item = SESSION::get_item_board_col( num );
+            if( item == ITEM_BOARD ) append_board = false;
+            if( item == ITEM_END ) break;
+            num++;
+        }
+        if( append_board ) APPEND_COLUMN( m_col_board, ITEM_NAME_BOARD, m_columns.m_col_board );
+    }
+
+    num = 0;
     for(;;){
         const int item = SESSION::get_item_board_col( num );
         if( item == ITEM_END ) break;
         switch( item ){
             case ITEM_MARK: APPEND_COLUMN( m_col_mark, ITEM_NAME_MARK, m_columns.m_col_mark ); break;
             case ITEM_ID: APPEND_COLUMN( m_col_id, ITEM_NAME_ID, m_columns.m_col_id ); break;
+            case ITEM_BOARD: APPEND_COLUMN( m_col_board, ITEM_NAME_BOARD, m_columns.m_col_board ); break;
             case ITEM_NAME: APPEND_COLUMN( m_col_subject, ITEM_NAME_NAME, m_columns.m_col_subject ); break;
             case ITEM_RES: APPEND_COLUMN( m_col_res, ITEM_NAME_RES, m_columns.m_col_res ); break;
             case ITEM_LOAD: APPEND_COLUMN( m_col_str_load, ITEM_NAME_LOAD, m_columns.m_col_str_load ); break;
@@ -387,6 +456,10 @@ void BoardViewBase::update_columns()
             width = SESSION::col_id();
             break;
 
+        case COL_BOARD:
+            width = SESSION::col_board();
+            break;
+
         case COL_SUBJECT:
             width = SESSION::col_subject();
             m_treeview.set_column_for_height( id );
@@ -492,6 +565,7 @@ const int BoardViewBase::get_title_id( const int col )
 
     if( title == ITEM_NAME_MARK ) id = COL_MARK;
     else if( title == ITEM_NAME_ID ) id = COL_ID;
+    else if( title == ITEM_NAME_BOARD ) id = COL_BOARD;
     else if( title == ITEM_NAME_NAME ) id = COL_SUBJECT;
     else if( title == ITEM_NAME_RES ) id = COL_RES;
     else if( title == ITEM_NAME_LOAD ) id = COL_STR_LOAD;
@@ -551,6 +625,10 @@ void BoardViewBase::save_column_width()
             SESSION::set_col_id( width );
             break;
 
+        case COL_BOARD:
+            SESSION::set_col_board( width );
+            break;
+
         case COL_SUBJECT:
             SESSION::set_col_subject( width );
             break;
@@ -590,7 +668,7 @@ void BoardViewBase::save_column_width()
 void BoardViewBase::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it )
 {
     Gtk::TreeModel::Row row = *it;
-    Gtk::TreePath path = m_liststore->get_path( row );
+    Gtk::TreePath path = GET_PATH( row );
 
 #ifdef _DEBUG
 //    std::cout << "BoardViewBase::slot_cell_data path = " << path.to_string() << std::endl;
@@ -639,8 +717,16 @@ void BoardViewBase::restore_sort()
     m_previous_col = DBTREE::board_view_sort_pre_column( get_url_board() );
     m_previous_sortmode = DBTREE::board_view_sort_pre_mode( get_url_board() );
 
-    Gtk::TreeModel::Children child = m_liststore->children();
-    if( child.size() ){
+    if( m_show_col_board ){
+
+        m_previous_col = m_col;
+        m_previous_sortmode = m_sortmode;
+
+        m_col = COL_BOARD;
+        m_sortmode = SORTMODE_ASCEND;
+    }
+
+    if( get_row_size() ){
         exec_sort();
         goto_top();
     }
@@ -723,6 +809,7 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
 {
     int num_a = 0, num_b = 0;
     int ret = 0;
+    DBTREE::ArticleBase *arta, *artb;
 
     const int UP = 1;
     const int DOWN = 2;
@@ -737,14 +824,16 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             if( sortmode == SORTMODE_MARK2 ){ // 新着をキャッシュの上に
 
                 if( num_a == COL_MARKVAL_NEWTHREAD
-                    && ( num_b != COL_MARKVAL_NEWTHREAD && num_b != COL_MARKVAL_BKMARKED_UPDATED 
-                         && num_b != COL_MARKVAL_BKMARKED_BROKEN_SUBJECT && num_b != COL_MARKVAL_BKMARKED ) ){
+                    && ( num_b != COL_MARKVAL_NEWTHREAD && num_b <= COL_MARKVAL_UPDATED )
+                    ){
+
                     num_a = DOWN; // 下で ret *= -1 しているので UP と DOWNを逆にする
                     num_b = UP;
                 }
                 else if( num_b == COL_MARKVAL_NEWTHREAD
-                         && ( num_a != COL_MARKVAL_NEWTHREAD && num_a != COL_MARKVAL_BKMARKED_UPDATED 
-                             && num_a != COL_MARKVAL_BKMARKED_BROKEN_SUBJECT && num_a != COL_MARKVAL_BKMARKED ) ){
+                         && ( num_a != COL_MARKVAL_NEWTHREAD && num_a <= COL_MARKVAL_UPDATED )
+                    ){
+
                     num_a = UP; // 下で ret *= -1 しているので UP と DOWNを逆にする
                     num_b = DOWN;
                 }
@@ -780,8 +869,8 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
         case COL_SUBJECT:
         {
             // 文字列の大小を数字に変換
-            Glib::ustring name_a = row_a[ m_columns.m_col_subject ]; 
-            Glib::ustring name_b = row_b[ m_columns.m_col_subject ]; 
+            const Glib::ustring name_a = row_a[ m_columns.m_col_subject ]; 
+            const Glib::ustring name_b = row_b[ m_columns.m_col_subject ]; 
             if( name_a < name_b ) { num_a = UP; num_b = DOWN; }
             else if( name_a > name_b ) { num_a = DOWN; num_b = UP; }
             break;
@@ -793,8 +882,10 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             break;
 
         case COL_STR_LOAD:
-            num_a = row_a[ m_columns.m_col_load ];
-            num_b = row_b[ m_columns.m_col_load ];
+            arta = row_a[ m_columns.m_col_article ];
+            artb = row_b[ m_columns.m_col_article ];
+            num_a = arta->get_number_load();
+            num_b = artb->get_number_load();
             break;
 
         case COL_STR_NEW:
@@ -803,8 +894,10 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             break;
 
         case COL_SINCE:
-            num_a = row_a[ m_columns.m_col_since_t ];
-            num_b = row_b[ m_columns.m_col_since_t ];
+            arta = row_a[ m_columns.m_col_article ];
+            artb = row_b[ m_columns.m_col_article ];
+            num_a = arta->get_since_time();
+            num_b = artb->get_since_time();
             break;
 
         case COL_WRITE:
@@ -816,6 +909,16 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             num_a = row_a[ m_columns.m_col_speed ];
             num_b = row_b[ m_columns.m_col_speed ];
             break;
+
+        case COL_BOARD:
+        {
+            // 文字列の大小を数字に変換
+            Glib::ustring name_a = row_a[ m_columns.m_col_board ]; 
+            Glib::ustring name_b = row_b[ m_columns.m_col_board ]; 
+            if( name_a < name_b ) { num_a = UP; num_b = DOWN; }
+            else if( name_a > name_b ) { num_a = DOWN; num_b = UP; }
+            break;
+        }
     }
 
     // 両方とも 0 より大きいか 0 より小さい場合は普通に比較
@@ -908,28 +1011,31 @@ void BoardViewBase::show_view()
 
     if( is_loading() ) return;
 
-    // DBに登録されてない
+    update_boardname();
+
+    m_pre_query = std::string();
+    m_last_access_time = DBTREE::board_last_access_time( get_url_board() );
+    
+    // オートリロードのカウンタを0にする
+    reset_autoreload_counter();
+
+    if( ! m_load_subject_txt ){
+
+        update_view();
+        return;
+    }
+
+    // download 開始
+    // 終わったら update_view() が呼ばれる
+
+    // DBに登録されてない時はロードしない
     if( get_url_board().empty() ){
         set_status( "invalid URL" );
         BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
         return;
     }
 
-    update_boardname();
-
-#if GTKMMVER >= 280
-    m_treeview.unset_model();
-#endif
-    m_liststore->clear();
-    m_pre_query = std::string();
-    m_last_access_time = DBTREE::board_last_access_time( get_url_board() );
     m_loading = true;
-    
-    // オートリロードのカウンタを0にする
-    reset_autoreload_counter();
-
-    // download 開始
-    // 終わったら update_view() が呼ばれる
     DBTREE::board_download_subject( get_url_board(), get_url() );
     set_status( "loading..." );
     BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
@@ -953,12 +1059,13 @@ void BoardViewBase::redraw_scrollbar()
 
 
 //
-// 色、フォントの更新
+// 色、フォント、表示内容の更新
 //
 void BoardViewBase::relayout()
 {
     m_treeview.init_color( COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN );
     m_treeview.init_font( CONFIG::get_fontname( FONT_BOARD ) );
+    update_item_all();
 }
 
 
@@ -966,52 +1073,67 @@ void BoardViewBase::relayout()
 //
 // view更新
 //
-void BoardViewBase::update_view_impl( std::list< DBTREE::ArticleBase* >& list_subject )
+void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >& list_subject, const bool loading_fin )
 {
-    m_loading = false;
-
 #ifdef _DEBUG
     const int code = DBTREE::board_code( get_url_board() );
     std::cout << "BoardViewBase::update_view_impl " << get_url()
-              << " code = " << code << std::endl;
+              << " code = " << code
+              << " size = " << list_subject.size()
+              << std::endl;
 #endif    
 
     // 画面消去
 #if GTKMMVER >= 280
     m_treeview.unset_model();
 #endif
-    m_liststore->clear();
 
-    // 自動ソート抑制
-    UNSORTED_COLUMN();
-
-    m_id = 0;
     if( list_subject.size() ){
 
-        std::list< DBTREE::ArticleBase* >::iterator it;
-        for( it = list_subject.begin(); it != list_subject.end(); ++it ){
+        m_liststore->clear();
 
-            DBTREE::ArticleBase* art = *( it );
+        unsorted_column();
 
-            prepend_row( art );
+        // 行の追加
+        for( int i = list_subject.size()-1; i >= 0;  --i ){
+
+            DBTREE::ArticleBase* art = list_subject[ i ];
+            prepend_row( art, i + 1 );
         }
 
 #if GTKMMVER >= 280
         m_treeview.set_model( m_liststore );
 #endif
 
-        if( m_list_draw_bg_articles.size() ) draw_bg_articles();
-        else restore_sort();
+        if( loading_fin ){
+            if( m_list_draw_bg_articles.size() ) draw_bg_articles();
+            else restore_sort();
+        }
     }
 
-    // ステータスバー更新
-    std::ostringstream ss_tmp;
-    ss_tmp << DBTREE::board_str_code( get_url_board() ) << " [ 全 " << m_id << " ] ";
-    set_status( ss_tmp.str() );
-    BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
+    if( loading_fin ){
 
-    // タブのアイコン状態を更新
-    BOARD::get_admin()->set_command( "toggle_icon", get_url() );
+        m_loading = false;
+
+        update_status();
+
+        // タブのアイコン状態を更新
+        BOARD::get_admin()->set_command( "toggle_icon", get_url() );
+    }
+}
+
+
+//
+// ステータスバー更新
+//
+void BoardViewBase::update_status()
+{
+        std::ostringstream ss_tmp;
+        if( m_load_subject_txt ) ss_tmp << DBTREE::board_str_code( get_url_board() ) << " ";
+        ss_tmp << "[ 全 " << get_row_size() << " ] ";
+
+        set_status( ss_tmp.str() );
+        BOARD::get_admin()->set_command( "set_status", get_url(), get_status() );
 }
 
 
@@ -1029,7 +1151,6 @@ void BoardViewBase::focus_out()
 {
     SKELETON::View::focus_out();
 
-    save_column_width();
     m_treeview.hide_tooltip();
 }
 
@@ -1052,12 +1173,10 @@ void BoardViewBase::slot_delete_logs()
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
     for( ; it != list_it.end(); ++it ){
+
         Gtk::TreeModel::Row row = *( *it );
-        const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
-#ifdef _DEBUG
-        std::cout << url << std::endl;
-#endif
-        CORE::core_set_command( "delete_article", url );
+        DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+        CORE::core_set_command( "delete_article", art->get_url() );
     }
 }
 
@@ -1278,6 +1397,11 @@ const bool BoardViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_menubar" );
             break;
 
+            // URLを開くダイアログを表示
+        case CONTROL::OpenURL:
+            CORE::core_set_command( "show_openurl_diag" );
+            break;
+
         default:
             return false;
     }
@@ -1310,7 +1434,7 @@ void BoardViewBase::goto_bottom()
 //
 // 指定したIDのスレに移動
 //
-void BoardViewBase::goto_num( const int num )
+void BoardViewBase::goto_num( const int num, const int )
 {
     if( ! num ) return;
 
@@ -1418,9 +1542,8 @@ void BoardViewBase::activate_act_before_popupmenu( const std::string& url )
             for( ; it != list_it.end(); ++it ){
 
                 Gtk::TreeModel::Row row = *( *it );
-                const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
-
-                if( DBTREE::article_is_cached( url ) ) {
+                DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+                if( art->is_cached() ) {
                     act->set_sensitive( true );
                     break;
                 }
@@ -1448,7 +1571,11 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 
     // お気に入りサブメニュー
     else if( url == "popup_menu_favorite" ){
-        popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite" ) );
+
+        const std::string url_board = path2url_board( m_path_selected );
+
+        if( url_board.empty() ) popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite_article" ) );
+        else popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_favorite" ) );
     }
 
     // 通常メニュー
@@ -1468,26 +1595,65 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 
 
 //
-// 特定の行だけの更新
+// 特定の行だけの表示内容更新
 //
-void BoardViewBase::update_item( const std::string& url, const std::string& id_dat )
+// url : subject.txt のアドレス
+// id : DAT の ID(拡張子付き)
+//
+// もし ID が empty() なら全ての行の表示内容を更新する
+//
+void BoardViewBase::update_item( const std::string& url, const std::string& id )
 {
-    if( get_url().find( url ) != 0 ) return;
+    if( is_loading() ) return;
+    if( ! get_row_size() ) return;
+    if( ! get_url_board().empty() && get_url_board() !=  url ) return;
+
+    if( id.empty() ){
+        update_item_all();
+        return;
+    }
+
+    const std::string url_dat = DBTREE::url_datbase( url ) + id;
 
 #ifdef _DEBUG
-    std::cout << "BoardViewBase::update_item " << get_url() << " id = " << id_dat << std::endl;
+    std::cout << "BoardViewBase::update_item " << get_url() << std::endl
+              << "url = " << url << " id = " << id << " url_dat = " << url_dat << std::endl;
 #endif
 
-    // 自動ソート抑制
-    UNSORTED_COLUMN();
-    
-    Gtk::TreeModel::Row row = get_row_from_url( id_dat );
-    if( row ){
+    unsorted_column();
+   
+    Gtk::TreeModel::Row row = get_row_from_url( url_dat );
+    if( row ) update_row_common( row );
+}
 
-        const std::string url_art = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
-        DBTREE::ArticleBase* art = DBTREE::get_article( url_art );
 
-        update_row_common( art, row );
+//
+// 全ての行の表示内容更新
+//
+void BoardViewBase::update_item_all()
+{
+
+#ifdef _DEBUG
+    std::cout << "BoardViewBase::update_item_all " << get_url() << std::endl;
+#endif
+
+    unsorted_column(); 
+   
+    Gtk::TreeModel::Children child = m_liststore->children();
+    Gtk::TreeModel::Children::iterator it;
+    for( it = child.begin() ; it != child.end() ; ++it ){
+
+        Gtk::TreeModel::Row row = *( it );
+        if( ! row ) continue;
+
+        DBTREE::ArticleBase* art = row[ m_columns.m_col_article ];
+        if( ! art ) continue;
+
+        // since と write の表示形式を変更
+        art->reset_since_date();
+        art->reset_write_date();
+
+        update_row_common( row );
     }
 }
 
@@ -1495,24 +1661,22 @@ void BoardViewBase::update_item( const std::string& url, const std::string& id_d
 //
 // 行を作って内容をセット
 //
-Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art )
+Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art, const int id )
 {
     Gtk::TreeModel::Row row = *( m_liststore->prepend() ); // append より prepend の方が速いらしい
 
-    ++m_id;
+    row[ m_columns.m_col_id ]  = id;
 
-    row[ m_columns.m_col_id ]  = m_id;
-    row[ m_columns.m_col_since ] = art->get_since_date();
-
-    if( art->get_status() & STATUS_NORMAL )
+    if( ( art->get_status() & STATUS_NORMAL ) && ! art->is_924() )
         row[ m_columns.m_col_speed ] = art->get_speed();
+
+    if( m_col_board ) row[ m_columns.m_col_board ] = DBTREE::board_name( art->get_url() );
         
-    row[ m_columns.m_col_since_t ] = art->get_since_time();
-    row[ m_columns.m_col_id_dat ] = art->get_id();
+    row[ m_columns.m_col_article ] = art;
 
     row[ m_columns.m_col_drawbg ] = false;
 
-    update_row_common( art, row );
+    update_row_common( row );
 
     return row;
 }
@@ -1521,8 +1685,9 @@ Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art )
 //
 // prepend_row() と update_item() で共通に更新する列
 //
-void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row& row )
+void BoardViewBase::update_row_common( Gtk::TreeModel::Row& row )
 {
+    DBTREE::ArticleBase* art = row[ m_columns.m_col_article ];
     if( art->empty() ) return;
 
     const int load = art->get_number_load();
@@ -1542,14 +1707,14 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
         snprintf( tmp, tmpsize, "%d", res - load );
         row[ m_columns.m_col_str_new ] = tmp;
 
-        row[ m_columns.m_col_load ] = load;
         row[ m_columns.m_col_new ] = res - load;
     }
     else{
         row[ m_columns.m_col_str_load ] = "";
         row[ m_columns.m_col_str_new ] = "";
 
-        row[ m_columns.m_col_load ] = -1;
+        // キャッシュが無い場合はソートの優先度を
+        // キャッシュがあって新着0の物より下げる
         row[ m_columns.m_col_new ] = -1;
     }
 
@@ -1618,8 +1783,21 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
         }
     }
 
+    // スレッド924
+    else if( art->is_924() ){
+
+        if( CONFIG::get_show_924() ){
+            mark_val = COL_MARKVAL_924;
+            icon = ICON::INFO;
+        }
+        else{
+            mark_val = COL_MARKVAL_NORMAL;
+            icon = ICON::TRANSPARENT;
+        }
+    }
+
     // キャッシュ無し、新着
-    else if( art->get_since_time() > m_last_access_time ){
+    else if( ! get_url_board().empty() && art->get_since_time() > m_last_access_time ){
         mark_val = COL_MARKVAL_NEWTHREAD;
         icon = ICON::NEWTHREAD;
     }
@@ -1636,6 +1814,10 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
     row[ m_columns.m_col_mark_val ] = mark_val;
     row[ m_columns.m_col_mark ] = ICON::get_icon( icon );
 
+    // スレ立て時間
+    if( ! art->is_924() ) row[ m_columns.m_col_since ] = art->get_since_date();
+    else row[ m_columns.m_col_since ] = std::string();
+
     // 書き込み時間
     if( art->get_write_time() ){
         row[ m_columns.m_col_write ] = art->get_write_date();
@@ -1643,6 +1825,8 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
     }
     else{
         row[ m_columns.m_col_write ] = std::string();
+
+        // DAT落ちしたスレや1000に到達したスレなどは書き込んでいてもソート時の優先度を下げる
         if( mark_val < COL_MARKVAL_NORMAL ) row[ m_columns.m_col_write_t ] = 0;
         else row[ m_columns.m_col_write_t ] = -1;
     }
@@ -1654,6 +1838,12 @@ void BoardViewBase::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel:
 //
 const bool BoardViewBase::slot_button_press( GdkEventButton* event )
 {
+#ifdef _DEBUG        
+    std::cout << "BoardViewBase::slot_button_press\n";
+#endif
+
+    m_clicked = true;
+
     // マウスジェスチャ
     get_control().MG_start( event );
 
@@ -1662,8 +1852,8 @@ const bool BoardViewBase::slot_button_press( GdkEventButton* event )
 
     // ダブルクリック
     // button_release_eventでは event->type に必ず GDK_BUTTON_RELEASE が入る
-    m_dblclick = false;
-    if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
+    m_dblclicked = false;
+    if( event->type == GDK_2BUTTON_PRESS ) m_dblclicked = true; 
 
     BOARD::get_admin()->set_command( "switch_admin" );
 
@@ -1677,6 +1867,9 @@ const bool BoardViewBase::slot_button_press( GdkEventButton* event )
 //
 const bool BoardViewBase::slot_button_release( GdkEventButton* event )
 {
+    if( ! m_clicked ) return true;
+    m_clicked = false;
+
     /// マウスジェスチャ
     const int mg = get_control().MG_end( event );
 
@@ -1689,6 +1882,13 @@ const bool BoardViewBase::slot_button_release( GdkEventButton* event )
         return true;
     }
 
+    // リサイズするときにラベルをドラッグした場合
+    if( event->window != m_treeview.get_bin_window()->gobj() ){
+
+        save_column_width();
+        return true;
+    }
+
     const int x = (int)event->x;
     const int y = (int)event->y;
     Gtk::TreeModel::Path path;
@@ -1702,19 +1902,16 @@ const bool BoardViewBase::slot_button_release( GdkEventButton* event )
         m_path_selected = path;
 
 #ifdef _DEBUG        
-        std::cout << "BoardViewBase::slot_button_press : path = " << path.to_string()
+        std::cout << "BoardViewBase::slot_button_release : path = " << path.to_string()
+                  << " title = " << column->get_title()
                   << " x = " << x << " y = " << y
                   << " cellheight = " << m_treeview.get_row_height() 
                   << " cell_x = " << cell_x << " cell_y = " << cell_y << std::endl;
 #endif
 
-        // リサイズするときにラベルをクリックすると行を開く問題の対処
-        // かなりその場しのぎな方法なのでGTKのバージョンが上がったら誤動作するかも
-        if( x == cell_x && y < m_treeview.get_row_height() ) return true;
-
         // ダブルクリックの処理のため一時的にtypeを切替える
         GdkEventType type_copy = event->type;
-        if( m_dblclick ) event->type = GDK_2BUTTON_PRESS;
+        if( m_dblclicked ) event->type = GDK_2BUTTON_PRESS;
 
         // スレを開く
         bool openarticle = get_control().button_alloted( event, CONTROL::OpenArticleButton );
@@ -1762,8 +1959,11 @@ const bool BoardViewBase::slot_motion_notify( GdkEventMotion* event )
     // ツールチップに文字列をセットする
     if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) ){
 
+        // 列幅よりもツールチップの幅が広い場合はツールチップを表示する
         m_treeview.set_tooltip_min_width( column->get_width() );
-        if( column->get_title() == ITEM_NAME_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
+
+        if( column->get_title() == ITEM_NAME_BOARD ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_board ) );
+        else if( column->get_title() == ITEM_NAME_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
         else if( column->get_title() == ITEM_NAME_SINCE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_since ) );
         else if( column->get_title() == ITEM_NAME_LASTWRITE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_write ) );
         else m_treeview.set_str_tooltip( std::string() );
@@ -1873,6 +2073,7 @@ void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_l
 
         CORE::DATA_INFO info;
         info.type = TYPE_FILE;
+        info.parent = NULL;
         info.url = MISC::remove_str( ( *it ), "file://" );
         list_info.push_back( info );
 
@@ -1891,13 +2092,11 @@ void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_l
 //
 void BoardViewBase::slot_bookmark( const int bookmark )
 {
-    const std::string datbase = DBTREE::url_datbase( get_url_board() );
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
     for( ; it != list_it.end(); ++it ){
         Gtk::TreeModel::Row row = *( *it );
-        const std::string url = datbase + row[ m_columns.m_col_id_dat ];
-        DBTREE::ArticleBase* art = DBTREE::get_article( url );
+        DBTREE::ArticleBase* art = row[ m_columns.m_col_article ];
         if( art ){
             bool set = bookmark;
             if( bookmark == BOOKMARK_AUTO ) set = ! art->is_bookmarked_thread();
@@ -2058,14 +2257,15 @@ void BoardViewBase::open_selected_rows()
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
     for( ; it != list_it.end(); ++it ){
-        Gtk::TreeModel::Row row = *( *it );
-        const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
 
         if( !list_url.empty() ) list_url += " ";
-        list_url += url;
+
+        Gtk::TreeModel::Row row = *( *it );
+        DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+        list_url += art->get_url();
 
         // datロード終了時に次スレ移行チェックを行う
-        DBTREE::article_set_url_pre_article( url, get_url_pre_article() );
+        art->set_url_pre_article( get_url_pre_article() );
     }
 
     CORE::core_set_command( "open_article_list", std::string(), list_url );
@@ -2080,11 +2280,20 @@ const std::string BoardViewBase::path2daturl( const Gtk::TreePath& path )
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
     if( !row ) return std::string();
 
-    const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
-    return url;
+    DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+    return art->get_url();
 }
 
 
+//
+// path -> 板URL変換
+// 
+const std::string BoardViewBase::path2url_board( const Gtk::TreePath& path )
+{
+    if( ! get_url_board().empty() ) return get_url_board();
+    if( path.empty() ) return std::string();
+    return DBTREE::url_subject( path2daturl( path ) );
+}
 
 
 //
@@ -2104,8 +2313,7 @@ const bool BoardViewBase::drawout()
     std::cout << "BoardViewBase::drawout query = " <<  query << std::endl;
 #endif
 
-    // 自動ソート抑制
-    UNSORTED_COLUMN();
+    unsorted_column();
 
     JDLIB::Regex regex;
     Gtk::TreeModel::Children child = m_liststore->children();
@@ -2255,7 +2463,10 @@ void BoardViewBase::operate_search( const std::string& controlid )
 //
 void BoardViewBase::show_preference()
 {
-    SKELETON::PrefDiag* pref =  CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, get_url_board() );
+    const std::string url_board = path2url_board( m_path_selected );
+    if( url_board.empty() ) return;
+
+    SKELETON::PrefDiag* pref =  CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, url_board );
     pref->run();
     delete pref;
 }
@@ -2351,12 +2562,12 @@ void BoardViewBase::slot_save_dat()
     for( ; it != list_it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *( *it );
-        const std::string url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
+        DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
 
-        if( ! DBTREE::article_is_cached( url ) ) continue;
+        if( ! art->is_cached() ) continue;
 
-        const std::string path_from = CACHE::path_dat( url );
-        const std::string path_to = path_dir + MISC::get_filename( url );
+        const std::string path_from = CACHE::path_dat( art->get_url() );
+        const std::string path_to = path_dir + MISC::get_filename( art->get_url() );
 
 #ifdef _DEBUG
         std::cout << "from = " << path_from  << std::endl;
@@ -2396,7 +2607,7 @@ void BoardViewBase::slot_save_dat()
 
                             // 名前変更
                         case Gtk::RESPONSE_YES:
-                            if( ! DBTREE::article_save_dat( url, path_to ) ) continue;
+                            if( ! art->save_dat( path_to ) ) continue;
 
                         default:
                             copy_file = false;
@@ -2427,6 +2638,18 @@ void BoardViewBase::slot_save_dat()
 }
 
 
+//
+// 次スレ検索
+//
+void BoardViewBase::slot_search_next()
+{
+    if( m_path_selected.empty() ) return;
+    const std::string url = path2daturl( m_path_selected );
+
+    CORE::core_set_command( "open_board_next", DBTREE::url_subject( url ) , url );
+}
+
+
 //
 // 選択したスレをあぼーん
 //
@@ -2484,11 +2707,13 @@ void BoardViewBase::set_article_to_buffer()
         for( ; it != list_it.end(); ++it ){
 
             Gtk::TreeModel::Row row = *( *it );
+            DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
             const Glib::ustring name = row[ m_columns.m_col_subject ];
 
             CORE::DATA_INFO info;
             info.type = TYPE_THREAD;
-            info.url = DBTREE::url_datbase( get_url_board() ) + row[ m_columns.m_col_id_dat ];
+            info.parent = BOARD::get_admin()->get_win();
+            info.url = art->get_url();
             info.name = name.raw();
             info.data = std::string();
             info.path = path.to_string();
@@ -2514,9 +2739,14 @@ void BoardViewBase::set_board_to_buffer()
 {
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
+
+    const std::string url_board = path2url_board( m_path_selected );
+    if( url_board.empty() ) return;
+
     info.type = TYPE_BOARD;
-    info.url = DBTREE::url_boardbase( get_url_board() );
-    info.name = DBTREE::board_name( get_url_board() );
+    info.parent = BOARD::get_admin()->get_win();
+    info.url = DBTREE::url_boardbase( url_board );
+    info.name = DBTREE::board_name( url_board );
     info.data = std::string();
     info.path = Gtk::TreePath( "0" ).to_string();
 
@@ -2558,9 +2788,8 @@ void BoardViewBase::draw_bg_articles()
     std::cout << "BoardViewBase::draw_bg_articles size = " << m_list_draw_bg_articles.size() << std::endl;
 #endif
 
-    // 自動ソート抑制
-    UNSORTED_COLUMN();
-
+    unsorted_column();
+    
     std::list< std::string >::const_iterator it = m_list_draw_bg_articles.begin();
     for( ; it != m_list_draw_bg_articles.end(); ++it ){
 
@@ -2575,7 +2804,7 @@ void BoardViewBase::draw_bg_articles()
         // row が無ければ作成
         if( ! row ){
             DBTREE::ArticleBase* art = DBTREE::get_article( url );
-            row = prepend_row( art );
+            row = prepend_row( art, get_row_size() + 1 );
         }
 
         // 強調表示
