@@ -41,11 +41,16 @@ std::string CACHE::path_conf()
     return CACHE::path_root() + "jd.conf";
 }
 
+std::string CACHE::path_conf_bkup()
+{
+    return CACHE::path_conf() + ".bkup";
+}
+
 
 // 旧設定ファイル
 std::string CACHE::path_conf_old()
 {
-    std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+    std::string home = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
 
     return home + "/.jdrc";
 }
@@ -83,7 +88,7 @@ std::string CACHE::path_root()
         if( root_path[ root_path.length() -1 ] != '/' ) root_path = root_path + "/";
 
         if( root_path[ 0 ] == '~' ){
-            std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+            std::string home = MISC::getenv_limited( ENV_HOME , MAX_SAFE_PATH );
             root_path.replace( 0, 1, home );
         }
     }
@@ -364,6 +369,15 @@ std::string CACHE::path_postlog()
 }
 
 
+//
+// メッセージログ（-lオプション）
+//
+std::string CACHE::path_msglog()
+{
+    return path_logroot() + "msglog";
+}
+
+
 //
 // 検索や名前などの補完情報
 //
@@ -637,9 +651,9 @@ bool CACHE::mkdir_logroot()
 size_t CACHE::load_rawdata( const std::string& path, std::string& str )
 {
     str.clear();
-    
     std::ifstream fin;
-    fin.open( path.c_str() );
+
+    fin.open( to_locale_cstr( path ) );
     if( !fin.is_open() ) return 0;
     getline( fin, str, '\0' );
     fin.close();
@@ -652,7 +666,8 @@ size_t CACHE::load_rawdata( const std::string& path, char* data, const size_t n
 {
     size_t count = 0;
     std::ifstream fin;
-    fin.open( path.c_str() );
+
+    fin.open( to_locale_cstr( path ), std::ios::binary );
     if( !fin.is_open() ) return 0;
     fin.read( data, n );
     count = fin.gcount();
@@ -668,14 +683,17 @@ size_t CACHE::save_rawdata( const std::string& path, const std::string& str, con
 }
 
 
-
 size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, const bool append )
 {
     size_t count = 0;
     size_t byte = 0;
     std::ofstream fout;
-    if( append ) fout.open( path.c_str(), std::ios::app );
-    else fout.open( path.c_str() );
+    std::ofstream::openmode fmode;
+    
+    if( append ) fmode = std::ios::app | std::ios::ate | std::ios::binary;
+    else fmode = std::ios::binary;
+    
+    fout.open( to_locale_cstr( path ), fmode );
     if( !fout.is_open() ){
         MISC::ERRMSG( "can't open " + path );
         return 0;
@@ -710,7 +728,17 @@ const int CACHE::file_exists( const std::string& path )
     struct stat buf_stat;
 
     if( path.empty() ) return EXIST_ERROR;
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return EXIST_ERROR;
+
+    std::string path_s = path;
+#ifdef _WIN32
+    // on windows fail stat() directory path with ends '/'
+    // "c:/" = ok, "c:" = fail
+    // "c:/dir/" = fail, "c:/dir" = ok
+    if( path.length() > 3 && path[ path.length() - 1 ] == '/' ){
+        path_s = path.substr( 0, path.length() - 1 );
+    }
+#endif
+    if( stat( to_locale_cstr( path_s ), &buf_stat ) != 0 ) return EXIST_ERROR;
 
     if( S_ISREG( buf_stat.st_mode ) ) return EXIST_FILE;
     if( S_ISDIR( buf_stat.st_mode ) ) return EXIST_DIR;
@@ -724,7 +752,7 @@ size_t CACHE::get_filesize( const std::string& path )
 {
     struct stat buf_stat;
 
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return 0;
+    if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return 0;
     if( S_ISREG( buf_stat.st_mode ) ) return buf_stat.st_size;
     return 0;
 }
@@ -734,7 +762,7 @@ time_t CACHE::get_filemtime( const std::string& path )
 {
     struct stat buf_stat;
 
-    if( stat( path.c_str(), &buf_stat ) != 0 ) return 0;
+    if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return 0;
     if( S_ISREG( buf_stat.st_mode ) ) return buf_stat.st_mtime;
     return 0;
 }
@@ -755,13 +783,18 @@ bool CACHE::jdmkdir( const std::string& path )
     
     if( path.find( "~/" ) == 0 ){
 
-        std::string homedir = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+        std::string homedir = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
         if( homedir.empty() ) return false;
 
         target = homedir + path.substr( 2 );
     }
 
+#ifdef _WIN32
+    // on windows has case of start drive letter "c:/...", or UNC "//pcname/..."
+    if( target[ 0 ] != '/' && target[ 1 ] != ':' ) return false;
+#else
     if( target[ 0 ] != '/' ) return false;
+#endif
     if( target[ target.length() -1 ] != '/' ) target += "/";
 
 #ifdef _DEBUG
@@ -782,7 +815,11 @@ bool CACHE::jdmkdir( const std::string& path )
         
         if( CACHE::file_exists( currentdir ) == EXIST_DIR ) continue;
 
-        if( mkdir( currentdir.c_str(), 0755 ) != 0 ){
+#ifdef _WIN32
+        if( mkdir( to_locale_cstr( currentdir ) ) != 0 ){
+#else
+        if( mkdir( to_locale_cstr( currentdir ), 0755 ) != 0 ){
+#endif
             MISC::ERRMSG( "mkdir failed " + currentdir );
             return false;
         }
@@ -799,7 +836,7 @@ bool CACHE::jdmkdir( const std::string& path )
 bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
 {
     struct stat buf_stat;
-    if( stat( file_from.c_str(), &buf_stat ) != 0 ) return false;
+    if( stat( to_locale_cstr( file_from ), &buf_stat ) != 0 ) return false;
 
 #ifdef _DEBUG
     std::cout << "CACHE::jdcopy : from = " << file_from << std::endl;
@@ -837,7 +874,7 @@ bool CACHE::jdcopy( const std::string& file_from, const std::string& file_to )
 bool CACHE::jdmv( const std::string& file_from, const std::string& file_to )
 {
     if( CACHE::jdcopy( file_from, file_to ) ){
-        unlink( file_from.c_str() );
+        unlink( to_locale_cstr( file_from ) );
         return true;
     }
 
@@ -873,7 +910,7 @@ std::string CACHE::copy_file( Gtk::Window* parent, const std::string& file_from,
 
     if( CACHE::jdcopy( file_from, path_to ) ) return path_to;
     else{
-        SKELETON::MsgDiag mdiag( parent, file_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
+        SKELETON::MsgDiag mdiag( parent, path_to + "\n\nの保存に失敗しました。\nハードディスクの容量やパーミッションなどを確認してください。" );
         mdiag.run();
     }
 
@@ -920,7 +957,7 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 const std::list< std::string > CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_path, const int type, const bool multi )
 {
     std::string dir = MISC::get_dir( open_path );
-    if( dir.empty() ) dir = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+    if( dir.empty() ) dir = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
 
     SKELETON::FileDiag diag( parent, "ファイルを開く", Gtk::FILE_CHOOSER_ACTION_OPEN );
 
@@ -932,7 +969,7 @@ const std::list< std::string > CACHE::open_load_diag( Gtk::Window* parent, const
     {
         diag.hide();
 
-        return diag.get_filenames();
+        return MISC::recover_path( diag.get_filenames() );
     }
 
     return std::list< std::string >();
@@ -957,7 +994,7 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
     SKELETON::FileDiag diag( parent, "保存先選択", Gtk::FILE_CHOOSER_ACTION_SAVE );
     if( dir.empty() )
     {
-        const std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+        const std::string home = MISC::getenv_limited( ENV_HOME, MAX_SAFE_PATH );
         if( ! home.empty() ) diag.set_current_folder( home );
     }
     else
@@ -969,8 +1006,8 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
 
     if( diag.run() != Gtk::RESPONSE_ACCEPT ) return std::string();
     diag.hide();
-        
-    std::string path_to = diag.get_filename();
+
+    std::string path_to = MISC::recover_path( diag.get_filename() );
 
 #ifdef _DEBUG
     std::cout << "to   = " << path_to  << std::endl;
@@ -1009,7 +1046,7 @@ std::list< std::string > CACHE::get_filelist( const std::string& dir )
     std::cout << "CACHE::get_filelist " << dir << std::endl;
 #endif
 
-    DIR *dirp = opendir( dir.c_str() );
+    DIR *dirp = opendir( to_locale_cstr( dir ) );
     if( !dirp ) return list_files;
 
     struct dirent *direntry;
@@ -1043,7 +1080,7 @@ int64_t CACHE::get_dirsize( const std::string& dir )
     std::cout << "CACHE::get_dirsize " << dir << std::endl;
 #endif
 
-    DIR *dirp = opendir( dir.c_str() );
+    DIR *dirp = opendir( to_locale_cstr( dir ) );
     if( !dirp ) return 0;
 
     struct dirent *direntry;
@@ -1068,10 +1105,14 @@ const std::string CACHE::get_realpath( const std::string& path )
 {
     std::string path_real;
 
-    char* ret = realpath( path.c_str(), NULL );
+    char resolved_path[ PATH_MAX + 1 ];
+#ifdef _WIN32
+    char* ret = _fullpath( resolved_path, to_locale_cstr( path ), PATH_MAX );
+#else
+    char* ret = realpath( to_locale_cstr( path ), resolved_path );
+#endif
     if( ret ){
         path_real = ret;
-        free( ret );
     }
     else return std::string();
 
