@@ -58,10 +58,12 @@ void AboutConfig::pack_widgets()
     column->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
     column->set_resizable( true );
     m_treeview.append_column( *column );
+    Gtk::CellRenderer *cell = column->get_first_cell_renderer();
+    if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &AboutConfig::slot_cell_data ) );
 
     column = Gtk::manage( new Gtk::TreeViewColumn( "値", m_columns.m_col_value ) );
     m_treeview.append_column( *column );
-    Gtk::CellRenderer *cell = column->get_first_cell_renderer();
+    cell = column->get_first_cell_renderer();
     if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &AboutConfig::slot_cell_data ) );
 
     m_scrollwin.add( m_treeview );
@@ -127,25 +129,27 @@ void AboutConfig::append_rows()
     append_row( "書き込み時のタイムアウト値(秒)", get_confitem()->loader_timeout_post, CONF_LOADER_TIMEOUT_POST );
     append_row( "画像等のデータのロード時のタイムアウト値(秒)", get_confitem()->loader_timeout_img, CONF_LOADER_TIMEOUT_IMG );
     append_row( "更新チェック時のタイムアウト値(秒)", get_confitem()->loader_timeout_checkupdate, CONF_LOADER_TIMEOUT_CHECKUPDATE );
-    append_row( "ダウンローダのバッファサイズ(kbyte)", get_confitem()->loader_bufsize, CONF_LOADER_BUFSIZE );
+    append_row( "一般データのダウンロード時のバッファサイズ(Kbyte)", get_confitem()->loader_bufsize, CONF_LOADER_BUFSIZE );
+    append_row( "スレ一覧のダウンロード時のバッファサイズ(Kbyte)", get_confitem()->loader_bufsize_board, CONF_LOADER_BUFSIZE_BOARD );
 
     // ツリービュー
     append_row( "" );
     append_row( "■ ツリービュー(板一覧、スレ一覧)" );
     append_row( "ツリービューでマウスホイールを回したときのスクロール量(行数)", get_confitem()->tree_scroll_size, CONF_TREE_SCROLL_SIZE );
-    append_row( "ツリービューの背景色設定にgtkrcを用いる", get_confitem()->use_tree_gtkrc, CONF_USE_TREE_GTKRC );
     append_row( "ツリービューの行間スペース", get_confitem()->tree_ypad, CONF_TREE_YPAD );
+    append_row( "カテゴリを開いたときにスクロールする", get_confitem()->scroll_tree, CONF_SCROLL_TREE );
 
     // 板一覧、お気に入り
     append_row( "" );
-    append_row( "■ 板一覧、お気に入り" );
+    append_row( "■ 板一覧、お気に入り、履歴" );
     append_row( "板移転時に確認ダイアログを表示する", get_confitem()->show_movediag, CONF_SHOW_MOVEDIAG );
     append_row( "板一覧内にあるリンクを全て板とみなす", get_confitem()->use_link_as_board, CONF_USE_LINK_AS_BOARD );
     append_row( "板一覧でカテゴリを常にひとつだけ開く", get_confitem()->open_one_category, CONF_OPEN_ONE_CATEGORY );
     append_row( "お気に入りでカテゴリを常にひとつだけ開く", get_confitem()->open_one_favorite, CONF_OPEN_ONE_FAVORITE );
     append_row( "右ペーンが空の時にサイドバーを最大化する", get_confitem()->expand_sidebar, CONF_EXPAND_SIDEBAR );
     append_row( "スレをお気に入りに追加した時にしおりをセットする", get_confitem()->bookmark_drop, CONF_BOOKMARK_DROP );
-    append_row( "お気に入りの更新チェック時に板の更新もチェックする", get_confitem()->check_update_board, CONF_CHECK_UPDATE_BOARD );
+    append_row( "更新チェック時に板の更新もチェックする", get_confitem()->check_update_board, CONF_CHECK_UPDATE_BOARD );
+    append_row( "起動時にお気に入りを自動でチェックする", get_confitem()->check_update_boot, CONF_CHECK_UPDATE_BOOT );
 
     // スレ一覧
     append_row( "" );
@@ -154,12 +158,15 @@ void AboutConfig::append_rows()
     append_row( "deleteを押したときに確認ダイアログを表示", get_confitem()->show_deldiag, CONF_SHOW_DELDIAG );
     append_row( "指定した値(時間)よりも後に立てられたスレを新着とみなす", get_confitem()->newthread_hour, CONF_NEWTHREAD_HOUR );
     append_row( "3ペーン時にスレ一覧やスレビューを最大化する", get_confitem()->expand_rpane, CONF_EXPAND_RPANE );
+    append_row( "スレ一覧をロードする前にキャッシュにある一覧を表示する", get_confitem()->show_cached_board, CONF_SHOW_CACHED_BOARD );
+    append_row( "お知らせスレ(924)のアイコンを表示する", get_confitem()->show_924, CONF_SHOW_924 );
 
     // 次スレ検索
     append_row( "" );
     append_row( "■ 次スレ検索" );
     append_row( "類似度判定のしきい値(小さいほど判定が甘くなる、最大10)", get_confitem()->threshold_next, CONF_THRESHOLD_NEXT );
     append_row( "移行時にお気に入りのアドレスと名前を自動更新する", get_confitem()->replace_favorite_next, CONF_REPLACE_FAVORITE_NEXT );
+    append_row( "お気に入り自動更新の確認ダイアログを表示する", get_confitem()->show_diag_replace_favorite, CONF_SHOW_DIAG_REPLACE_FAVORITE );
 
     // スレビュー
     append_row( "" );
@@ -199,6 +206,7 @@ void AboutConfig::append_rows()
     append_row( "書き込み中ダイアログを表示しない", get_confitem()->hide_writing_dialog, CONF_HIDE_WRITING_DIALOG );
     append_row( "アスキーアートメニューの履歴の保持数", get_confitem()->aahistory_size, CONF_AAHISTORY );
     append_row( "書き込みログの最大サイズ(バイト)", get_confitem()->maxsize_postlog, CONF_MAXSIZE_POSTLOG );
+    append_row( "ビューを閉じても書き込み欄の日本語のON/OFF状態を保つ", get_confitem()->keep_im_status, CONF_KEEP_IM_STATUS );
 
     // 画像
     append_row( "" );
@@ -212,6 +220,7 @@ void AboutConfig::append_rows()
     append_row( "画像ビューのスムージングレベル(0-2, 大きい程高画質で低速)", get_confitem()->imgmain_interp, CONF_IMGMAIN_INTERP );
     append_row( "埋め込み画像のスムージングレベル(0-2, 大きい程高画質で低速)", get_confitem()->imgemb_interp, CONF_IMGEMB_INTERP );
     append_row( "ポップアップ画像のスムージングレベル(0-2, 大きい程高画質で低速)", get_confitem()->imgpopup_interp, CONF_IMGPOPUP_INTERP );
+    append_row( "画像のメモリキャッシュ枚数", get_confitem()->imgcache_size, CONF_IMGCACHE_SIZE );
 
     // ウィンドウ
     append_row( "" );
@@ -224,7 +233,8 @@ void AboutConfig::append_rows()
     // その他
     append_row( "" );
     append_row( "■ その他" );
-    append_row( "履歴の保持数", get_confitem()->history_size, CONF_HISTORY );
+    append_row( "履歴メニューの表示数", get_confitem()->history_size, CONF_HISTORY_SIZE );
+    append_row( "履歴ビューの表示数", get_confitem()->historyview_size, CONF_HISTORYVIEW_SIZE );
     append_row( "マウスジェスチャの判定開始半径", get_confitem()->mouse_radius, CONF_MOUSE_RADIUS );
     append_row( "起動時に開いていたスレ一覧を復元する", get_confitem()->restore_board, CONF_RESTORE_BOARD );
     append_row( "起動時に開いていたスレを復元する", get_confitem()->restore_article, CONF_RESTORE_ARTICLE );
@@ -236,6 +246,7 @@ void AboutConfig::append_rows()
     append_row( "スレタイ検索用のアドレス", get_confitem()->url_search_title, CONF_URL_SEARCH_TITLE );
     append_row( "スレタイ検索時にアドレスとスレタイを取得する正規表現", get_confitem()->regex_search_title, CONF_REGEX_SEARCH_TITLE );
     append_row( "Ctrl+qでウィンドウを閉じない", get_confitem()->disable_close, CONF_DISABLE_CLOSE );
+    append_row( "書き込み履歴のあるスレを削除する時にダイアログを表示", get_confitem()->show_del_written_thread_diag, CONF_SHOW_DEL_WRITTEN_THREAD_DIAG );
 }
 
 
@@ -316,8 +327,8 @@ void AboutConfig::set_value( Gtk::TreeModel::Row& row, const int& value )
 
 void AboutConfig::set_value( Gtk::TreeModel::Row& row, const bool& value )
 {
-    if( value ) row[ m_columns.m_col_value ] = "true";
-    else row[ m_columns.m_col_value ] = "false";
+    if( value ) row[ m_columns.m_col_value ] = "はい";
+    else row[ m_columns.m_col_value ] = "いいえ";
 
     const bool defaultval = row[ m_columns.m_col_default_bool ];
     if( value != defaultval ) row[ m_columns.m_col_drawbg ] = true;
