@@ -20,7 +20,7 @@
 
 #include "command_args.h"
 
-class WinMain;
+class JDWinMain;
 
 
 namespace BOARD
@@ -70,7 +70,7 @@ namespace CORE
         std::list< COMMAND_ARGS > m_list_command;
         sigc::connection m_sigc_switch_page;
 
-        WinMain& m_win_main;
+        JDWinMain& m_win_main;
 
         SKELETON::JDHPaned m_hpaned;
 
@@ -96,6 +96,8 @@ namespace CORE
         std::string m_title;
 
         Gtk::MenuBar* m_menubar;
+        Gtk::MenuItem *m_menuitem_prevview;
+        Gtk::MenuItem *m_menuitem_nextview;
 
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
@@ -106,7 +108,7 @@ namespace CORE
 
     public:
 
-        Core( WinMain& win_main );
+        Core( JDWinMain& win_main );
         virtual ~Core();
 
         Gtk::Widget* get_toplevel();
@@ -140,6 +142,10 @@ namespace CORE
         void slot_style_changed( Glib::RefPtr< Gtk::Style > );
 
         void slot_activate_menubar();
+        void slot_activate_historymenu();
+
+        void slot_prevview();
+        void slot_nextview();
 
         void slot_clear_board();
         void slot_clear_thread();
@@ -152,6 +158,7 @@ namespace CORE
         
         void toggle_menubar();
         void toggle_flat_button();
+        void toggle_draw_toolbarback();
         void toggle_post_mark();
         void toggle_sidebar();
         void slot_show_hide_leftpane( int mode );
@@ -192,21 +199,17 @@ namespace CORE
         void set_sensitive_view_button();
         void toggle_maximize_rightpane();
 
-        void switch_article( bool present );
-        void switch_board( bool present );
-        void switch_sidebar( const std::string& url, bool present );
-        void switch_image( bool present );
-        void switch_message( bool present );
+        void switch_article( const bool present );
+        void switch_board( const bool present );
+        void switch_sidebar( const std::string& url, const bool present );
+        void switch_image( const bool present );
+        void switch_message( const bool present );
 
         void toggle_article();
         void switch_leftview();
         void switch_rightview();
         void open_by_browser( const std::string& url );
 
-        void set_history_article( const std::string& url );
-        void set_history_board( const std::string& url );
-        void set_history_close( const std::string& url );
-
         // 画像インジケータ表示/非表示
         void show_imagetab();
         void hide_imagetab();
@@ -218,6 +221,7 @@ namespace CORE
         //
         // メニュー関係( menuslots.cpp の中に記述)
         //
+        void slot_openurl();
         void slot_toggle_online();
         void slot_toggle_login2ch();
         void slot_toggle_loginbe();
@@ -226,7 +230,9 @@ namespace CORE
         void slot_save_favorite();
         void slot_quit();
         ///
-        void slot_toggle_toolbarpos( int pos );
+        void slot_toggle_since( const int mode );
+        void slot_toggle_write( const int mode );
+        void slot_toggle_toolbarpos( const int pos );
         void slot_toggle_toolbarbbslist();
         void slot_toggle_toolbarboard();
         void slot_toggle_toolbararticle();
@@ -241,12 +247,13 @@ namespace CORE
         void slot_toggle_use_imgpopup();
         void slot_toggle_use_inlineimg();
         void slot_toggle_show_ssspicon();
-        void slot_setup_boarditemcolumn();
+        void slot_setup_boarditem_column();
         void slot_setup_mainitem();
         void slot_setup_sidebaritem();
         void slot_setup_boarditem();
         void slot_setup_articleitem();
         void slot_setup_msgitem();
+        void slot_setup_articleitem_menu();
         //
         void slot_board_pref();
         void slot_article_pref();
@@ -292,6 +299,8 @@ namespace CORE
         void slot_live_start_stop();
         void slot_search_cache_board();
         void slot_search_cache();
+        void slot_show_cache_board();
+        void slot_show_cache();
         void slot_search_title();
         void slot_check_update_root();
         void slot_check_update_open_root();
