@@ -81,7 +81,8 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
-      m_save_info( 0 )
+      m_save_info( 0 ),
+      m_924( false )
 {
 #ifdef _DEBUG
 //    std::cout << "ArticleBase::ArticleBase : " << m_id << std::endl;
@@ -138,6 +139,19 @@ const std::string ArticleBase::get_org_url()
 }
 
 
+// スレ立て時刻( string型 )
+const std::string& ArticleBase::get_since_date()
+{
+    if( m_since_date.empty()
+        || SESSION::get_col_since_time() == MISC::TIME_PASSED ){
+
+        m_since_date = MISC::timettostr( get_since_time(), SESSION::get_col_since_time() );
+    }
+
+    return m_since_date;
+}
+
+
 // スレ速度
 const int ArticleBase::get_speed()
 {
@@ -272,9 +286,20 @@ std::list< int > ArticleBase::get_res_posted()
 //
 // number番のレスを参照しているレス番号をリストにして取得
 //
-std::list< int > ArticleBase::get_res_reference( int number )
+std::list< int > ArticleBase::get_res_reference( const int number )
 {
-    return get_nodetree()->get_res_reference( number );
+    std::list< int > res_num;
+    res_num.push_back( number );
+    return get_res_reference( res_num );
+}
+
+
+//
+// res_num に含まれるレスを参照しているレス番号をリストにして取得
+//
+std::list< int > ArticleBase::get_res_reference( const std::list< int >& res_num )
+{
+    return get_nodetree()->get_res_reference( res_num );
 }
 
 
@@ -381,8 +406,8 @@ void ArticleBase::set_org_host( const std::string& host )
 #ifdef _DEBUG
     std::cout << "ArticleBase::set_org_host : " << m_id << std::endl
               << "m_url = " << m_url << std::endl
-              << "host = " << host << std::endl
-              << "org_host = " << m_org_host << std::endl;
+              << "org_host = " << m_org_host
+              << " -> " << host << std::endl;
 #endif
 
         m_org_host = host;
@@ -434,9 +459,13 @@ void ArticleBase::set_subject( const std::string& subject )
 }
 
 
-void ArticleBase::set_number( const int number )
+void ArticleBase::set_number( const int number, const bool is_online )
 {
-    if( number && number > m_number ){
+    if( ! number ) return;
+
+    m_status &= ~STATUS_BROKEN_SUBJECT;
+
+    if( number > m_number ){
 
         m_number = number;
 
@@ -444,6 +473,15 @@ void ArticleBase::set_number( const int number )
         // お気に入りとスレビューのタブのアイコンに更新マークを表示
         if( is_cached() && !( m_status & STATUS_UPDATE ) && m_number_load < m_number ) show_updateicon( true );
     }
+
+    // subject.txt に示されたレス数よりも実際の取得数の方が多い
+    else if( is_online && number < m_number ){
+#ifdef _DEBUG
+        std::cout << "ArticleBase::set_number : broken_subject " << get_subject() << " "
+                  << number << " / " << m_number << std::endl;
+#endif
+        m_status |= STATUS_BROKEN_SUBJECT;
+    }
 }
 
 
@@ -462,6 +500,22 @@ void ArticleBase::set_number_seen( const int number_seen )
 }
 
 
+// 最終書き込み時間( string型 )
+const std::string& ArticleBase::get_write_date()
+{
+    if( m_write_time.tv_sec ){
+
+        if( m_write_time_date.empty() 
+            || SESSION::get_col_write_time() == MISC::TIME_PASSED ){
+        
+            m_write_time_date = MISC::timettostr( m_write_time.tv_sec, SESSION::get_col_write_time() );
+        }
+    }
+
+    return m_write_time_date;
+}
+
+
 //
 // 書き込み時間更新
 //
@@ -472,7 +526,6 @@ void ArticleBase::update_writetime()
     if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
 
         m_write_time = tv;
-        m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
 
 #ifdef _DEBUG
         std::cout << "ArticleBase::update_writetime : " << m_write_time.tv_sec << " " << m_write_time_date << std::endl;
@@ -705,10 +758,11 @@ void ArticleBase::add_abone_word( const std::string& word )
 //
 // レスあぼーんのセット
 //
-void ArticleBase::set_abone_res( const int number, const bool set )
+void ArticleBase::set_abone_res( const int num_from, const int num_to, const bool set )
 {
     if( empty() ) return;
-    if( number <= 0 || number > MAX_RESNUMBER ) return;
+    if( num_from > num_to ) return;
+    if( num_from <= 0 || num_to >= MAX_RESNUMBER ) return;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::set_abone_res num = " << number << " set = " << set << std::endl;
@@ -716,7 +770,7 @@ void ArticleBase::set_abone_res( const int number, const bool set )
 
     if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
 
-    m_vec_abone_res[ number ] = set;
+    for( int i = num_from; i <= num_to; ++i ) m_vec_abone_res[ i ] = set;
 
     update_abone();
 
@@ -942,6 +996,16 @@ const bool ArticleBase::is_loading()
 }
 
 
+//
+// 更新チェック中か
+//
+const bool ArticleBase::is_checking_update()
+{
+    if( ! is_loading() ) return false;
+
+    return m_nodetree->is_checking_update();
+}
+
 
 //
 // ロード停止
@@ -976,28 +1040,27 @@ void ArticleBase::download_dat( const bool check_update )
     struct timezone tz;
     if( gettimeofday( &tv, &tz ) != 0 ) tv.tv_sec = 0;
 
+    // 更新チェック可能か判定する
     if( check_update ){
 
-        if( ! SESSION::is_online() ) return;
-
-        // 既に更新状態の時はチェックしない
-        if( enable_load() ){
-
-            // 次のスレを更新チェック
-            CORE::get_checkupdate_manager()->pop_front();
-
-            return;
-        }
-
         // 一度更新チェックしたらしばらくは再チェックできないようにする
         time_t passed = 0;
         if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
 
+        if( ! SESSION::is_online()
+            || is_loading()
+            || enable_load() // 既に新着あり状態の時はチェックしない
+            || ( m_status & STATUS_OLD )
+            || ( passed <= CHECKUPDATE_MINSEC )
+            )
+        {
 #ifdef _DEBUG
-        std::cout << "check_update passed = " << passed << std::endl;
+            std::cout << "skipped : passed = " << passed << " enable_load = " << enable_load()
+                      << " loading = " << is_loading()
+                      << std::endl;
 #endif
-
-        if( passed <= CHECKUPDATE_MINSEC ) return;
+            return;
+        }
     }
 
     if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
@@ -1007,7 +1070,7 @@ void ArticleBase::download_dat( const bool check_update )
 #ifdef _DEBUG
         std::cout << "old !\n";
 #endif       
-        CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+        CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
 
         // update_article_finish コマンドを送らないとキャッシュが無くて
         // dat落ちしているスレのタブが空白になる
@@ -1144,10 +1207,10 @@ void ArticleBase::slot_load_finished()
     if( m_code != HTTP_ERR ){
 
         // DAT落ち
-        if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
+        if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND || m_code == HTTP_OLD ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
-            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
         }
 
         // 既にDAT落ち状態では無いときは通常状態にする
@@ -1234,7 +1297,7 @@ void ArticleBase::slot_load_finished()
 #endif
             int value = 0;
 
-            const std::list< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
+            const std::vector< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
 
             // subjectがキャッシュにある場合は TFIDF を使って類似度チェック
             if( list_subject.size() ){
@@ -1392,12 +1455,20 @@ void ArticleBase::show_updateicon( const bool update )
             // スレビューのタブのアイコン表示を更新
             CORE::core_set_command( "toggle_article_icon", m_url);
 
-            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
         }
     }
     else{
 
-        if( m_status & STATUS_UPDATE ){
+        // この if をコメントアウトしないと
+        //
+        // スレ一覧を開いてお気に入りにあるスレに更新マークを付ける → スレ一覧を閉じる
+        // 更新マークを付けたスレを開かないでJD終了(※) → 再起動してお気に入りで更新マークを付けたスレをクリック
+        // → お気に入りのアイコン表示が戻らない
+        //
+        // という問題が生じる( ※ の所でスレ情報が保存されていないので再起動すると STATUS_UPDATE が外れるため。
+        // 終了時にスレ情報を保存しようとすると終了処理が重くなる。)
+//        if( m_status & STATUS_UPDATE ){
 
 #ifdef _DEBUG
             std::cout << "toggle_icon off\n";
@@ -1406,10 +1477,10 @@ void ArticleBase::show_updateicon( const bool update )
             m_save_info = true;
             m_status &= ~STATUS_UPDATE;
 
-            // お気に入りのアイコン表示を戻す
+            // サイドバーのアイコン表示を戻す
             // スレビューのタブのアイコンはArticleViewがロード終了時に自動的に戻す
-            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
-        }
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
+//        }
     }
 }
 
@@ -1427,11 +1498,30 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     if( empty() ) return;
 
-    if( ! cache_only && m_bookmarked_thread ){
-        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。"
-                                  ,false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-        mdiag.set_default_response( Gtk::RESPONSE_YES );
-        if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+
+    if( ! cache_only ){
+
+        if( m_bookmarked_thread ){
+
+            const std::string msg = "「" + get_subject() +
+            "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。";
+
+            SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_YES );
+            if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+        }
+        else if( CONFIG::get_show_del_written_thread_diag() && m_write_time.tv_sec ){
+
+            const std::string msg = "「" + get_subject() + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
+
+            SKELETON::MsgCheckDiag mdiag( NULL, msg,
+                                          "今後表示しない(常に削除)(_D)",
+                                          Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+
+            if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_del_written_thread_diag( false );
+        }
     }
 
     m_number_load = m_number_seen = m_number_before_load = 0;
@@ -1469,10 +1559,10 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_bookmarked_thread = false;
     
         // info 削除
-        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
+        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( m_path_article_info ) );
 
         // 拡張info 削除
-        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
+        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( m_path_article_ext_info ) );
 
         // お気に入りから削除
         CORE::core_set_command( "remove_favorite", m_url );
@@ -1480,13 +1570,13 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     // キャッシュ削除
     std::string path_dat = CACHE::path_dat( m_url );
-    if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( path_dat.c_str() );
+    if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( path_dat ) );
 
     // BoardViewの行を更新
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
 
-    // お気に入りのアイコン表示を戻す
-    CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+    // サイドバーのアイコン表示を戻す
+    CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
 }
 
 
@@ -1536,6 +1626,9 @@ void ArticleBase::read_info()
 
     m_read_info = true;
 
+    const int status_old = m_status;
+    bool saveinfo = false;
+
     // 情報ファイルのパスをセット
     if( m_path_article_info.empty() ) SET_INFOPATH();
 
@@ -1591,8 +1684,6 @@ void ArticleBase::read_info()
                 m_write_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
                 m_write_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
             }
-
-            if( m_write_time.tv_sec ) m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
         }
 
         // write name
@@ -1736,7 +1827,7 @@ void ArticleBase::read_info()
         }
         
         m_number_before_load = m_number_load;
-        m_save_info = true;
+        saveinfo = true;
         unlock_impl();
 
 #ifdef _DEBUG
@@ -1746,6 +1837,16 @@ void ArticleBase::read_info()
 
     if( m_number < m_number_load ) m_number = m_number_load;
 
+    // infoファイル読み込み前に既にDAT落ち状態になっていた場合は
+    // 状態を DAT 落ちに戻しておく
+    if( ( status_old & STATUS_OLD ) && ( m_status & STATUS_NORMAL ) ){
+        m_status &= ~STATUS_NORMAL;
+        m_status |= STATUS_OLD;
+        saveinfo = true;
+    }
+
+    if( saveinfo ) save_info( true );
+
 #ifdef _DEBUG
     std::cout << "ArticleBase::read_info file = " << m_path_article_ext_info << std::endl;
 
@@ -1810,6 +1911,7 @@ void ArticleBase::save_info( const bool force )
     m_save_info = false;
 
     if( m_path_article_ext_info.empty() ) return;
+    if( ! CACHE::mkdir_boardroot( m_url ) ) return;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::save_info force = " << force << std::endl;
