@@ -161,6 +161,15 @@ const bool DBTREE::move_board( const std::string& url_old, const std::string& ur
     return get_root()->move_board( url_old, url_new, false );
 }
 
+void DBTREE::set_enable_save_movetable( const bool set )
+{
+    get_root()->set_enable_save_movetable( set );
+}
+
+void DBTREE::save_movetable()
+{
+    get_root()->save_movetable();
+}
 
 const XML::Document& DBTREE::get_xml_document()
 {
@@ -323,6 +332,13 @@ const std::string DBTREE::board_ext( const std::string& url )
     return DBTREE::get_board( url )->get_ext();
 }
 
+
+const int DBTREE::board_status( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_status();
+}
+
+
 const int DBTREE::board_code( const std::string& url )
 {
     return DBTREE::get_board( url )->get_code();
@@ -343,7 +359,7 @@ void DBTREE::board_save_info( const std::string& url )
 
 void DBTREE::board_download_subject( const std::string& url, const std::string& url_update_view )
 {
-    DBTREE::get_board( url )->download_subject( url_update_view );
+    DBTREE::get_board( url )->download_subject( url_update_view, false );
 }
 
 const bool DBTREE::board_is_loading( const std::string& url )
@@ -357,7 +373,7 @@ void DBTREE::board_stop_load( const std::string& url )
 }
 
 
-std::list< DBTREE::ArticleBase* >& DBTREE::board_list_subject( const std::string& url )
+std::vector< DBTREE::ArticleBase* >& DBTREE::board_list_subject( const std::string& url )
 {
     return DBTREE::get_board( url )->get_list_subject();
 }
@@ -524,14 +540,15 @@ void DBTREE::read_boardinfo_all()
     DBTREE::get_root()->read_boardinfo_all();
 }
 
-std::list< std::string > DBTREE::search_cache_all( const std::string& url, const std::string& query, bool mode_or, bool& stop )
+void DBTREE::search_cache_all( std::vector< DBTREE::ArticleBase* >& list_article,
+                               const std::string& query, const bool mode_or, const bool& stop )
 {
-    return DBTREE::get_root()->search_cache( query, mode_or, stop );
+    DBTREE::get_root()->search_cache( list_article, query, mode_or, stop );
 }
 
-std::list< std::string > DBTREE::search_cache( const std::string& url, const std::string& query, bool mode_or, bool& stop )
+void DBTREE::search_cache( const std::string& url, std::vector< DBTREE::ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool& stop )
 {
-    return DBTREE::get_board( url )->search_cache( query, mode_or, stop );
+    DBTREE::get_board( url )->search_cache( list_article, query, mode_or, stop );
 }
 
 void DBTREE::board_update_writetime( const std::string& url )
@@ -564,6 +581,21 @@ time_t DBTREE::board_write_leftsec( const std::string& url )
     return DBTREE::get_board( url )->get_write_leftsec();
 }
 
+void DBTREE::board_show_updateicon( const std::string& url, const bool update )
+{
+    DBTREE::get_board( url )->show_updateicon( update );
+}
+
+const std::list< std::string > DBTREE::board_get_check_update_articles( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_check_update_articles();
+}
+
+// datファイルのインポート
+const std::string DBTREE::board_import_dat( const std::string& url, const std::string& filename )
+{
+    return DBTREE::get_board( url )->import_dat( filename );
+}
 
 // 板に属する全スレの書き込み履歴のリセット
 void DBTREE::board_clear_all_post_history( const std::string& url )
@@ -600,74 +632,67 @@ const time_t DBTREE::board_last_access_time( const std::string& url )
 
 /////////////////////////////////////////////////
 
-std::list< std::string > DBTREE::get_abone_list_id_board( const std::string& url )
+
+const std::list< std::string >& DBTREE::get_abone_list_id_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_id();
+    return DBTREE::get_board( url )->get_abone_list_id_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_name_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_name_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_name();
+    return DBTREE::get_board( url )->get_abone_list_name_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_word();
+    return DBTREE::get_board( url )->get_abone_list_word_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_regex();
+    return DBTREE::get_board( url )->get_abone_list_regex_board();
 }
 
 void DBTREE::reset_abone_board( const std::string& url,
-                        std::list< std::string >& ids, std::list< std::string >& names,
-                        std::list< std::string >& words, std::list< std::string >& regexs )
+                                const std::list< std::string >& ids,
+                                const std::list< std::string >& names,
+                                const std::list< std::string >& words,
+                                const std::list< std::string >& regexs )
 {
-    DBTREE::get_board( url )->reset_abone( ids, names, words, regexs );
+    DBTREE::get_board( url )->reset_abone_board( ids, names, words, regexs );
 }
 
 
 void DBTREE::add_abone_id_board( const std::string& url, const std::string& id )
 {
-    DBTREE::get_board( url )->add_abone_id( id );
+    DBTREE::get_board( url )->add_abone_id_board( id );
 }
 
 void DBTREE::add_abone_name_board( const std::string& url, const std::string& name )
 {
-    DBTREE::get_board( url )->add_abone_name( name );
+    DBTREE::get_board( url )->add_abone_name_board( name );
 }
 
 void DBTREE::add_abone_word_board( const std::string& url, const std::string& word )
 {
-    DBTREE::get_board( url )->add_abone_word( word );
+    DBTREE::get_board( url )->add_abone_word_board( word );
 }
 
 
 /////////////////////////////////////////////////
 
 
-void DBTREE::update_abone_all_board()
-{
-    DBTREE::get_root()->update_abone_all_board();
-}
-
-void DBTREE::update_abone_board( const std::string& url )
-{
-    DBTREE::get_board( url )->update_abone_thread();
-}
-
-std::list< std::string > DBTREE::get_abone_list_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_thread();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_word_thread();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_regex_thread();
 }
@@ -683,9 +708,22 @@ const int DBTREE::get_abone_hour_thread( const std::string& url )
 }
 
 
+void DBTREE::remove_old_abone_thread( const std::string& url )
+{
+    DBTREE::get_board( url )->remove_old_abone_thread();
+}
+
+void DBTREE::update_abone_thread()
+{
+    DBTREE::get_root()->update_abone_thread();
+}
+
 void DBTREE::reset_abone_thread( const std::string& url,
-                                 std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
-                                 const int number, const int hour )
+                                 const std::list< std::string >& threads,
+                                 const std::list< std::string >& words,
+                                 const std::list< std::string >& regexs,
+                                 const int number,
+                                 const int hour )
 {
     DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour );
 }
@@ -769,12 +807,6 @@ const int DBTREE::article_status( const std::string& url )
 }
 
 
-void DBTREE::article_reset_status( const std::string& url )
-{
-    DBTREE::get_article( url )->reset_status();
-}
-
-
 const int DBTREE::article_code( const std::string& url )
 {
     return DBTREE::get_article( url )->get_code();
@@ -826,6 +858,11 @@ const bool DBTREE::article_is_loading( const std::string& url )
     return DBTREE::get_article( url )->is_loading();
 }
 
+const bool DBTREE::article_is_checking_update( const std::string& url )
+{
+    return DBTREE::get_article( url )->is_checking_update();
+}
+
 void DBTREE::article_download_dat( const std::string& url, const bool check_update )
 {
     DBTREE::get_article( url )->download_dat( check_update );
@@ -978,6 +1015,12 @@ const std::string DBTREE::create_newarticle_message( const std::string& url, con
 }
 
 
+const std::string DBTREE::get_write_referer( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_write_referer();
+}
+
+
 // キャッシュ削除
 void DBTREE::delete_article( const std::string& url, const bool cache_only )
 {
@@ -1012,46 +1055,49 @@ void DBTREE::update_abone_all_article()
 }
 
 
-std::list< std::string > DBTREE::get_abone_list_id( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_id( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_id();
 }
 
 
-std::list< std::string > DBTREE::get_abone_list_name( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_name( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_name();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_word();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_regex();
 }
 
 
-std::vector< char > DBTREE::get_abone_vec_res( const std::string& url )
+const std::vector< char >& DBTREE::get_abone_vec_res( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_vec_res();
 }
 
 
-void DBTREE::reset_abone( const std::string& url, std::list< std::string >& ids, std::list< std::string >& names
-                          , std::list< std::string >& words, std::list< std::string >& regexs
-                          , std::vector< char >& vec_abone_res
-                          , bool transparent, bool chain)
+void DBTREE::reset_abone( const std::string& url,
+                          const std::list< std::string >& ids,
+                          const std::list< std::string >& names,
+                          const std::list< std::string >& words,
+                          const std::list< std::string >& regexs,
+                          const std::vector< char >& vec_abone_res,
+                          const bool transparent, const bool chain, const bool age )
 {
-    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain );
+    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age );
 }
 
 
-void DBTREE::set_abone_res( const std::string& url, const int number, const bool set )
+void DBTREE::set_abone_res( const std::string& url, const int num_from, const int num_to, const bool set )
 {
-    DBTREE::get_article( url )->set_abone_res( number, set );
+    DBTREE::get_article( url )->set_abone_res( num_from, num_to, set );
 }
 
 
@@ -1072,30 +1118,45 @@ void DBTREE::add_abone_word( const std::string& url, const std::string& word )
 }
 
 
+// 透明あぼーん
 const bool DBTREE::get_abone_transparent( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_transparent();
 }
 
 
-void DBTREE::set_abone_transparent( const std::string& url, bool set )
+void DBTREE::set_abone_transparent( const std::string& url, const bool set )
 {
     DBTREE::get_article( url )->set_abone_transparent( set );
 }
 
 
+// 連鎖あぼーん
 const bool DBTREE::get_abone_chain( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_chain();
 }
 
 
-void DBTREE::set_abone_chain( const std::string& url, bool set )
+void DBTREE::set_abone_chain( const std::string& url, const bool set )
 {
     DBTREE::get_article( url )->set_abone_chain( set );
 }
 
 
+// ageあぼーん
+const bool DBTREE::get_abone_age( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_age();
+}
+
+
+void DBTREE::set_abone_age( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_age( set );
+}
+
+
 const bool DBTREE::is_bookmarked_thread( const std::string& url )
 {
     return DBTREE::get_article( url )->is_bookmarked_thread();
@@ -1112,13 +1173,13 @@ const int DBTREE::get_num_bookmark( const std::string& url )
     return DBTREE::get_article( url )->get_num_bookmark();
 }
 
-const bool DBTREE::is_bookmarked( const std::string& url, int number )
+const bool DBTREE::is_bookmarked( const std::string& url, const int number )
 {
     return DBTREE::get_article( url )->is_bookmarked( number );
 }
 
 
-void DBTREE::set_bookmark( const std::string& url, int number, bool set )
+void DBTREE::set_bookmark( const std::string& url, const int number, const bool set )
 {
     DBTREE::get_article( url )->set_bookmark( number, set );
 }
