@@ -66,6 +66,7 @@ Root::Root()
     , m_analyzing_board_xml( false )
     , m_board_null( 0 )
     , m_get_board( NULL )
+    , m_enable_save_movetable( true )
 {
     m_document.clear();
     clear();
@@ -231,8 +232,14 @@ BoardBase* Root::get_board( const std::string& url, const int count )
                        << "新 URL  = " << board->url_boardbase() << std::endl;
                     MISC::MSG( ss.str() );
 
-                    //移転テーブル保存
-                    save_movetable();
+                    if( m_enable_save_movetable ){
+
+                        //移転テーブル保存
+                        save_movetable();
+
+                        // サイドバーに登録されているURL更新
+                        CORE::core_set_command( "update_sidebar_item" );
+                    }
 
                     BoardBase* board = get_board( url, count + 1 );
                     m_get_board_url = url;
@@ -327,7 +334,7 @@ void Root::receive_finish()
 {
     if( get_code() != HTTP_OK ){
 
-        std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗しました。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
+        std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗したため板一覧は更新されませんでした。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
         SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_ERROR );
         mdiag.run();
         MISC::ERRMSG( "bbsmenu load failed : " + get_str_code() );
@@ -475,8 +482,14 @@ void Root::analyze_board_xml()
         diag.resize( 600, 400 );
         diag.run();
 
-        //移転テーブル保存
-        save_movetable();
+        if( m_enable_save_movetable ){
+
+            //移転テーブル保存
+            save_movetable();
+
+            // サイドバーに登録されているURL更新
+            CORE::core_set_command( "update_sidebar_item" );
+        }
     }
 
     m_analyzing_board_xml = false;
@@ -608,7 +621,7 @@ bool Root::set_board( const std::string& url, const std::string& name, const std
         if( m_analyzing_board_xml && m_analyzed_path_board.find( path_board ) != m_analyzed_path_board.end() ){
 
             std::string tmp_msg = "Root::set_board : The XML file is broken !\n";
-            tmp_msg += url + " has already been registerd as " + board->url_boardbase();
+            tmp_msg += url + " has already been registered as " + board->url_boardbase();
             MISC::ERRMSG( tmp_msg );
 
             const std::string path1 = CACHE::path_board_root_fast( board->url_boardbase() );
@@ -683,7 +696,16 @@ const bool Root::move_board( const std::string& url_old, const std::string& url_
             ) ) return false;
 
     // キャッシュを移動した
-    if( ! m_move_info.empty() ) save_movetable();
+    if( ! m_move_info.empty() ){
+
+        if( m_enable_save_movetable ){
+
+            save_movetable();
+
+            // サイドバーに登録されているURL更新
+            CORE::core_set_command( "update_sidebar_item" );
+        }
+    }
 
     return true;
 }
@@ -1286,8 +1308,14 @@ const std::string Root::is_board_moved( const std::string& url,
 
                     MISC::MSG( str );
 
-                    //移転テーブル保存
-                    save_movetable();
+                    if( m_enable_save_movetable ){
+
+                        //移転テーブル保存
+                        save_movetable();
+
+                        // サイドバーに登録されているURL更新
+                        CORE::core_set_command( "update_sidebar_item" );
+                    }
 
                     // 改めてもう一度実行
                     return is_board_moved( url, old_root, old_path_board, new_root, new_path_board, 0 ); 
@@ -1357,21 +1385,14 @@ void Root::read_boardinfo_all()
 }
 
 // 全ログ検索
-std::list< std::string > Root::search_cache( const std::string& query, bool mode_or, bool& stop )
+void Root::search_cache( std::vector< ArticleBase* >& list_article,
+                         const std::string& query, const bool mode_or, const bool& stop )
 {
-    std::list< std::string > m_urllist;
-
     std::list< BoardBase* >::iterator it;
     for( it = m_list_board.begin(); it != m_list_board.end(); ++it ){
-
-        std::list< std::string > m_tmplist;
-        m_tmplist = ( *it )->search_cache( query, mode_or, stop );
-        m_urllist.splice( m_urllist.end(), m_tmplist );
-
+        ( *it )->search_cache( list_article, query, mode_or, stop );
         if( stop ) break;
     }
-
-    return m_urllist;
 }
 
 
@@ -1415,15 +1436,6 @@ void Root::save_movetable()
 #endif
     
     CACHE::save_rawdata( file_move, movetable.str() );
-
-    // 板一覧に登録されているURL更新
-    CORE::core_set_command( "update_bbslist_item" );
-
-    // お気に入りに登録されているURL更新
-    CORE::core_set_command( "update_favorite_item" );
-
-    // 履歴メニューのURL更新
-    CORE::core_set_command( "update_history" );
 }
 
 
