@@ -26,6 +26,9 @@ enum{
 // SKELETON::SelectItemPrefの項目名
 #define ITEM_NAME_BBSLISTVIEW "板一覧"
 #define ITEM_NAME_FAVORITEVIEW "お気に入り"
+#define ITEM_NAME_HISTVIEW "スレ履歴"
+#define ITEM_NAME_HIST_BOARDVIEW "板履歴"
+#define ITEM_NAME_HIST_CLOSEVIEW "最近閉じたスレ"
 #define ITEM_NAME_BOARDVIEW "スレ一覧"
 #define ITEM_NAME_ARTICLEVIEW "スレビュー"
 #define ITEM_NAME_IMAGEVIEW "画像ビュー"
@@ -35,6 +38,7 @@ enum{
 
 #define ITEM_NAME_MARK  "!"
 #define ITEM_NAME_ID    "番号"
+#define ITEM_NAME_BOARD "板"
 #define ITEM_NAME_NAME  "タイトル"
 #define ITEM_NAME_RES   "レス"
 #define ITEM_NAME_LOAD  "取得"
@@ -46,11 +50,16 @@ enum{
 #define ITEM_NAME_WRITEMSG  "書き込み"
 #define ITEM_NAME_OPENBOARD "板を開く"
 #define ITEM_NAME_SEARCH    "検索"
+#define ITEM_NAME_DRAWOUT    "抽出"
 #define ITEM_NAME_RELOAD    "再読み込み"
 #define ITEM_NAME_STOPLOADING "読み込み中止"
 #define ITEM_NAME_FAVORITE  "お気に入りに追加"
-#define ITEM_NAME_CHECK_UPDATE_ROOT "お気に入り更新チェック"
-#define ITEM_NAME_CHECK_UPDATE_OPEN_ROOT "お気に入り更新チェックしてタブで開く"
+#define ITEM_NAME_CHECK_UPDATE_ROOT "更新チェック"
+#define ITEM_NAME_CHECK_UPDATE_OPEN_ROOT "更新チェックしてタブで開く"
+#define ITEM_NAME_COPY      "コピー"
+#define ITEM_NAME_COPY_URL      "URLをコピー"
+#define ITEM_NAME_COPY_TITLE_URL "タイトルとURLをコピー"
+#define ITEM_NAME_COPY_TITLE_URL_THREAD "スレのタイトルとURLをコピー"
 #define ITEM_NAME_DELETE    "削除"
 #define ITEM_NAME_QUIT      "閉じる"
 #define ITEM_NAME_PREVVIEW  "前へ戻る"
@@ -70,6 +79,17 @@ enum{
 #define ITEM_NAME_UNDO        "元に戻す(Undo)"
 #define ITEM_NAME_REDO        "やり直し(Redo)"
 
+#define ITEM_NAME_NGWORD      "NGワード"
+#define ITEM_NAME_ABONE_SELECTION "選択範囲のレスをあぼ〜ん"
+#define ITEM_NAME_QUOTE_SELECTION   "引用してレスする"
+#define ITEM_NAME_OPEN_BROWSER      "ブラウザで開く"
+#define ITEM_NAME_USER_COMMAND      "ユーザコマンド"
+#define ITEM_NAME_ETC         "その他"
+#define ITEM_NAME_SAVE_DAT    "datを保存"
+#define ITEM_NAME_COPY_THREAD_INFO   "スレ情報のコピー"
+
+#define ITEM_NAME_PREF_THREAD    "スレのプロパティ"
+
 
 // SESSION::get_item_*() の戻り値
 enum
@@ -77,6 +97,9 @@ enum
     ITEM_BBSLISTVIEW = 0,
     ITEM_FAVORITEVIEW,
     ITEM_BOARDVIEW,
+    ITEM_HISTVIEW,
+    ITEM_HIST_BOARDVIEW,
+    ITEM_HIST_CLOSEVIEW,
     ITEM_ARTICLEVIEW,
     ITEM_IMAGEVIEW,
     ITEM_URL,
@@ -85,6 +108,7 @@ enum
 
     ITEM_MARK,
     ITEM_ID,
+    ITEM_BOARD,
     ITEM_NAME,
     ITEM_RES,
     ITEM_LOAD,
@@ -96,11 +120,16 @@ enum
     ITEM_WRITEMSG,
     ITEM_OPENBOARD,
     ITEM_SEARCH,
+    ITEM_DRAWOUT,
     ITEM_RELOAD,
     ITEM_STOPLOADING,
     ITEM_FAVORITE,
     ITEM_CHECK_UPDATE_ROOT,
     ITEM_CHECK_UPDATE_OPEN_ROOT,
+    ITEM_COPY,
+    ITEM_COPY_URL,
+    ITEM_COPY_TITLE_URL,
+    ITEM_COPY_TITLE_URL_THREAD,
     ITEM_DELETE,
     ITEM_QUIT,
     ITEM_PREVVIEW,
@@ -120,6 +149,17 @@ enum
     ITEM_UNDO,
     ITEM_REDO,
 
+    ITEM_NGWORD,
+    ITEM_ABONE_SELECTION,
+    ITEM_QUOTE_SELECTION,
+    ITEM_OPEN_BROWSER,
+    ITEM_USER_COMMAND,
+    ITEM_ETC,
+    ITEM_SAVE_DAT,
+    ITEM_COPY_THREAD_INFO,
+
+    ITEM_PREF_THREAD,
+
     ITEM_END
 };
 
@@ -133,6 +173,7 @@ enum
     STATUS_BROKEN = 4,   // あぼーんなどで壊れている
     STATUS_UPDATE = 8,   // 更新可能
     STATUS_UPDATED = 16,   // 更新済み
+    STATUS_BROKEN_SUBJECT = 32  // subject.txt が壊れている( subject.txt に示されたレス数よりも実際の取得数の方が多い )
 };
 
 
@@ -156,8 +197,10 @@ enum
 // 実況スクロールモード
 enum
 {
-    LIVE_SCRMODE_VARIABLE = 0,
-    LIVE_SCRMODE_STEADY
+    LIVE_SCRMODE_VARIABLE = 0,  // 速度可変、速度がしきい値を越えると行単位でスクロール
+    LIVE_SCRMODE_STEADY, // 速度一定、遅れがしきい値を越えると行単位でスクロール
+
+    LIVE_SCRMODE_NUM
 };
 
 
@@ -181,16 +224,18 @@ enum
 #define URL_LOGINP2 "jdlogin://loginp2"
 
 #define URL_BBSLISTADMIN "jdadmin://bbslist"
+#define URL_BOARDADMIN "jdadmin://board"
+#define URL_ARTICLEADMIN "jdadmin://article"
+#define URL_IMAGEADMIN "jdadmin://image"
+#define URL_MESSAGEADMIN "jdadmin://message"
+
 #define URL_BBSLISTVIEW "jdview://bbslist"
 #define URL_FAVORITEVIEW "jdview://favorite"
+#define URL_HISTTHREADVIEW "jdview://histthread"
+#define URL_HISTBOARDVIEW "jdview://histboard"
+#define URL_HISTCLOSEVIEW "jdview://histclose"
 
-#define URL_BOARDADMIN "jdadmin://board"
-
-#define URL_ARTICLEADMIN "jdadmin://article"
-
-#define URL_IMAGEADMIN "jdadmin://image"
-
-#define URL_MESSAGEADMIN "jdadmin://message"
+#define URL_ALLLOG "jdview://alllog"
 
 #define URL_USRCMD "jdpref://usrcmd"
 #define URL_LINKFILTER "jdpref://linkfilter"
