@@ -12,11 +12,13 @@
 #include "globalabonethreadpref.h"
 #include "fontcolorpref.h"
 #include "livepref.h"
+#include "openurldiag.h"
 
 #include "mainitempref.h"
 #include "sidebaritempref.h"
 #include "boarditempref.h"
 #include "articleitempref.h"
+#include "articleitemmenupref.h"
 #include "msgitempref.h"
 
 #include "dbimg/delimgdiag.h"
@@ -31,7 +33,7 @@
 
 #include "config/aboutconfig.h"
 
-SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const std::string& url )
+SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, const int type, const std::string& url, const std::string command )
 {
     switch( type )
     {
@@ -71,7 +73,7 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
         case PREFDIAG_SIDEBARITEM:
             return new CORE::SidebarItemPref( parent, url );            
 
-        case PREFDIAG_BOARDITEMCOLUM:
+        case PREFDIAG_BOARDITEM_COLUM:
             return new CORE::BoardItemColumnPref( parent, url );            
 
         case PREFDIAG_BOARDITEM:
@@ -80,6 +82,9 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
         case PREFDIAG_ARTICLEITEM:
             return new CORE::ArticleItemPref( parent, url );            
 
+        case PREFDIAG_ARTICLEITEM_MENU:
+            return new CORE::ArticleItemMenuPref( parent, url );
+
         case PREFDIAG_MSGITEM:
             return new CORE::MsgItemPref( parent, url );            
 
@@ -87,10 +92,10 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
             return new DBIMG::DelImgDiag( parent, url );
 
         case PREFDIAG_BOARD:
-            return new BOARD::Preferences( parent, url );
+            return new BOARD::Preferences( parent, url, command );
 
         case PREFDIAG_ARTICLE:
-            return new ARTICLE::Preferences( parent, url );
+            return new ARTICLE::Preferences( parent, url, command );
 
         case PREFDIAG_IMAGE:
             return new IMAGE::Preferences( parent, url );
@@ -107,8 +112,10 @@ SKELETON::PrefDiag* CORE::PrefDiagFactory( Gtk::Window* parent, int type, const
         case PREFDIAG_ABOUTCONFIG:
             return new CONFIG::AboutConfig( parent );
 
+        case PREFDIAG_OPENURL:
+            return new CORE::OpenURLDialog( url );
+
         default:
             return NULL;
     }
 }
-
