@@ -8,6 +8,7 @@
 #include "view.h"
 #include "dragnote.h"
 #include "msgdiag.h"
+#include "tabswitchmenu.h"
 
 #include "dbtree/interface.h"
 
@@ -32,6 +33,16 @@ enum
 };
 
 
+// open_view で使うモード
+enum
+{
+    OPEN_MODE_AUTO = 1,
+    OPEN_MODE_NOSWITCH = 2,
+    OPEN_MODE_LOCK = 4,
+    OPEN_MODE_OFFLINE = 8
+};
+
+
 using namespace SKELETON;
 
 
@@ -40,6 +51,8 @@ Admin::Admin( const std::string& url )
       m_win( NULL ),
       m_notebook( NULL ),
       m_focus( false ),
+      m_move_menu( NULL ),
+      m_tabswitchmenu( NULL ),
       m_use_viewhistory( false )
 {
     m_notebook = new DragableNoteBook();
@@ -47,11 +60,14 @@ Admin::Admin( const std::string& url )
     m_notebook->signal_switch_page().connect( sigc::mem_fun( *this, &Admin::slot_switch_page ) );
     m_notebook->set_scrollable( true );
 
-    m_notebook->sig_tab_click().connect( sigc::mem_fun( *this, &Admin::slot_tab_click ) );
+    m_notebook->sig_tab_clicked().connect( sigc::mem_fun( *this, &Admin::slot_tab_clicked ) );
+    m_notebook->sig_tab_scrolled().connect( sigc::mem_fun( *this, &Admin::slot_tab_scrolled ) );
     m_notebook->sig_tab_close().connect( sigc::mem_fun( *this, &Admin::slot_tab_close ) );
     m_notebook->sig_tab_reload().connect( sigc::mem_fun( *this, &Admin::slot_tab_reload ) );
     m_notebook->sig_tab_menu().connect( sigc::mem_fun( *this, &Admin::slot_tab_menu ) );
 
+    m_notebook->get_tabswitch_button().signal_clicked().connect( sigc::mem_fun(*this, &Admin::slot_show_tabswitchmenu ) );
+
     // D&D
     m_notebook->sig_drag_data_get().connect( sigc::mem_fun(*this, &Admin::slot_drag_data_get ) );
 
@@ -90,13 +106,15 @@ Admin::~Admin()
     delete_jdwin();
 
     if( m_notebook ) delete m_notebook;
+    if( m_move_menu ) delete m_move_menu;
+    if( m_tabswitchmenu ) delete m_tabswitchmenu;
 }
 
 
 //
 // メニューのセットアップ
 //
-void Admin::setup_menu( const bool enable_checkupdate )
+void Admin::setup_menu()
 {
     // 右クリックメニュー
     m_action_group = Gtk::ActionGroup::create();
@@ -105,7 +123,7 @@ void Admin::setup_menu( const bool enable_checkupdate )
     m_action_group->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする(_K)", std::string(), false ),
                          sigc::mem_fun( *this, &Admin::slot_lock ) );
 
-    m_action_group->add( Gtk::Action::create( "Close_Tab_Menu", "複数のタブを閉じる(_L)" ) );
+    m_action_group->add( Gtk::Action::create( "Close_Tab_Menu", "複数のタブを閉じる(_T)" ) );
     m_action_group->add( Gtk::Action::create( "CloseOther", "他のタブ(_O)" ), sigc::mem_fun( *this, &Admin::slot_close_other_tabs ) );
     m_action_group->add( Gtk::Action::create( "CloseLeft", "左←のタブ(_L)" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
     m_action_group->add( Gtk::Action::create( "CloseRight", "右→のタブ(_R)" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
@@ -118,9 +136,11 @@ void Admin::setup_menu( const bool enable_checkupdate )
     m_action_group->add( Gtk::Action::create( "ReloadAll", "再読み込み(_R)" ), sigc::mem_fun( *this, &Admin::slot_reload_all_tabs ) );
     m_action_group->add( Gtk::Action::create( "CancelReloadAll", "キャンセル(_C)" ), sigc::mem_fun( *this, &Admin::slot_cancel_reload_all_tabs ) );
 
-    m_action_group->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)" ), sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
-    m_action_group->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)" ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
-    m_action_group->add( Gtk::Action::create( "CopyTitle", "タイトルとURLをコピー(_T)" ), sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
+    m_action_group->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
+                         sigc::mem_fun( *this, &Admin::slot_open_by_browser ) );
+    m_action_group->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &Admin::slot_copy_url ) );
+    m_action_group->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
+                         sigc::mem_fun( *this, &Admin::slot_copy_title_url ) );
 
     m_action_group->add( Gtk::Action::create( "Preference", "プロパティ(_P)..."), sigc::mem_fun( *this, &Admin::show_preference ) );
 
@@ -156,16 +176,10 @@ void Admin::setup_menu( const bool enable_checkupdate )
     "<separator/>"
 
     "<menu action='Reload_Tab_Menu'>"
-    "<menuitem action='ReloadAll'/>";
+    "<menuitem action='ReloadAll'/>"
 
-    if( enable_checkupdate ){
-
-        str_ui += 
-        "<menuitem action='CheckUpdateAll'/>"
-        "<menuitem action='CheckUpdateReloadAll'/>";
-    }
-
-    str_ui +=
+    "<menuitem action='CheckUpdateAll'/>"
+    "<menuitem action='CheckUpdateReloadAll'/>"
 
     "<separator/>"
     "<menuitem action='CancelReloadAll'/>"
@@ -176,7 +190,7 @@ void Admin::setup_menu( const bool enable_checkupdate )
     "<separator/>"
 
     "<menuitem action='CopyURL'/>"
-    "<menuitem action='CopyTitle'/>"
+    "<menuitem action='CopyTitleURL'/>"
 
     "<separator/>"
     "<menuitem action='Preference'/>"
@@ -191,16 +205,8 @@ void Admin::setup_menu( const bool enable_checkupdate )
     Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu" ) );
     Gtk::MenuItem* item;
 
-    // 移動サブメニュー作成と登録
-    for( int i = 0; i < MAX_TABS; ++i ){
-        item = Gtk::manage( new Gtk::MenuItem( "dummy" ) );
-        item->signal_activate().connect( sigc::bind< int >( sigc::mem_fun( *this, &Admin::set_current_page ), i ) );
-
-        m_vec_movemenu_items.push_back( item );
-        m_vec_movemenu_append.push_back( false );
-    }
-
-    m_move_menu = Gtk::manage( new Gtk::Menu() );
+    // 移動サブメニュー
+    m_move_menu = new SKELETON::TabSwitchMenu( m_notebook, this );
 
     // 進む、戻る
     Glib::RefPtr< Gtk::Action > act;
@@ -219,20 +225,19 @@ void Admin::setup_menu( const bool enable_checkupdate )
     // 先頭、最後に移動
     item = Gtk::manage( new Gtk::MenuItem( "先頭のタブに移動(_H)", true ) );
     m_move_menu->append( *item );
-    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_head ) );
+    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_head_focus ) );
 
     item = Gtk::manage( new Gtk::MenuItem( "最後のタブに移動(_T)", true ) );
     m_move_menu->append( *item );
-    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_tail ) );
+    item->signal_activate().connect( sigc::mem_fun( *this, &Admin::tab_tail_focus ) );
 
     m_move_menu->append( *Gtk::manage( new Gtk::SeparatorMenuItem() ) );
 
-    item  = Gtk::manage( new Gtk::MenuItem( "移動" ) );
-    item->set_submenu( *m_move_menu );
-    m_vec_movemenu_items.push_back( item );
+    m_move_menuitem  = Gtk::manage( new Gtk::MenuItem( "移動" ) );
+    m_move_menuitem->set_submenu( *m_move_menu );
 
-    popupmenu->insert( *item, 0 );
-    item->show_all();
+    popupmenu->insert( *m_move_menuitem, 0 );
+    m_move_menuitem->show_all();
 
     item = Gtk::manage( new Gtk::SeparatorMenuItem() );
     popupmenu->insert( *item, 1 );
@@ -240,6 +245,14 @@ void Admin::setup_menu( const bool enable_checkupdate )
 
     // ポップアップメニューにアクセレータを表示
     CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu->signal_deactivate().connect( sigc::mem_fun( *this, &Admin::slot_popupmenu_deactivate ) );
+}
+
+
+void Admin::slot_popupmenu_deactivate()
+{
+    if( m_move_menu ) m_move_menu->deactivate();
 }
 
 
@@ -482,10 +495,19 @@ void Admin::exec_command()
         switch_view( command.url );
     }
     else if( command.command == "tab_left" ){
-        tab_left();
+        tab_left( false );
     }
     else if( command.command == "tab_right" ){
-        tab_right();
+        tab_right( false );
+    }
+    else if( command.command == "tab_left_updated" ){
+        tab_left( true );
+    }
+    else if( command.command == "tab_right_updated" ){
+        tab_right( true );
+    }
+    else if( command.command == "tab_num" ){
+        tab_num( command.arg1 );
     }
     else if( command.command == "tab_head" ){
         tab_head();
@@ -609,7 +631,7 @@ void Admin::exec_command()
         focus_toolbar_search();
     }
 
-    // ツールバー表示切り替え
+    // ツールバー表示/非表示切り替え
     else if( command.command == "toggle_toolbar" ){
         toggle_toolbar();
     }
@@ -845,7 +867,7 @@ void Admin::update_status( View* view, const bool force )
 // "left" ならアクティブな左に開く
 // "page数字" なら指定した位置にタブで開く
 //
-// command.arg2: "true" なら既にurlを開いているかチェックしない
+// command.arg2: "true" なら既に command.url を開いているかチェックしない
 //
 // command.arg3: モード
 //
@@ -854,8 +876,12 @@ void Admin::update_status( View* view, const bool force )
 // スレ番号ジャンプなどで使用する
 //
 // "noswitch"ならタブを切り替えない(連続して開くときに使用)
+//
 // "lock" なら開いてからロックする
 //
+// "offline" なら オフラインで開く
+//
+//
 // その他のargは各ビュー別の設定
 //
 void Admin::open_view( const COMMAND_ARGS& command )
@@ -870,16 +896,27 @@ void Admin::open_view( const COMMAND_ARGS& command )
     SKELETON::View* view;
     SKELETON::View* current_view = get_current_view();
 
+    const bool online = SESSION::is_online();
+    const bool nocheck_opened = ( command.arg2 == "true" );
+    int mode = 0;
+    if( ! command.arg3.empty() ){
+
+        if( command.arg3.find( "auto" ) != std::string::npos ) mode |= OPEN_MODE_AUTO;
+        if( command.arg3.find( "noswitch" ) != std::string::npos ) mode |= OPEN_MODE_NOSWITCH;
+        if( command.arg3.find( "lock" ) != std::string::npos ) mode |= OPEN_MODE_LOCK;
+        if( command.arg3.find( "offline" ) != std::string::npos ) mode |= OPEN_MODE_OFFLINE;
+    }
+
     if( current_view ) current_view->focus_out();
 
     // urlを既に開いていたら表示してリロード
-    if( ! ( command.arg2 == "true" ) ){
+    if( ! nocheck_opened ){
 
-        view = get_view( command.url );
+        view = get_view( command_to_url( command ) );
         if( view ){
 
             // タブの切り替え
-            if( ! ( command.arg3 == "noswitch" ) ){
+            if( ! ( mode & OPEN_MODE_NOSWITCH ) ){
             
                 int page = m_notebook->page_num( *view );
 #ifdef _DEBUG
@@ -890,12 +927,16 @@ void Admin::open_view( const COMMAND_ARGS& command )
             }
 
             // オートモードは切り替えのみ
-            if( command.arg3 == "auto" ) return;
+            if( mode & OPEN_MODE_AUTO ) return;
 
             // ロック
-            if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
+            if( mode & OPEN_MODE_LOCK ) lock( m_notebook->page_num( *view ) );
+
+            // オフラインで開く
+            if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
 
             view->show_view();
+            SESSION::set_online( online );
 
             return;
         }
@@ -907,7 +948,7 @@ void Admin::open_view( const COMMAND_ARGS& command )
     const int page = m_notebook->get_current_page();
     const bool open_tab = (  page == -1
                              || ( ! command.arg1.empty() && command.arg1 != "false" )
-                             || command.arg3 == "auto" // オートモードの時もタブで開く
+                             || ( mode & OPEN_MODE_AUTO ) // オートモードの時もタブで開く
                              || is_locked( page )
         );
 
@@ -975,19 +1016,24 @@ void Admin::open_view( const COMMAND_ARGS& command )
 
     m_notebook->show_all();
     view->show();
+
+    // オフラインで開く
+    if( mode & OPEN_MODE_OFFLINE ) SESSION::set_online( false );
+
     view->show_view();
+    SESSION::set_online( online );
 
     // ツールバーの情報更新
     m_notebook->set_current_toolbar( view->get_id_toolbar(), view );
 
     // タブの切り替え
-    if( ! ( command.arg3 == "noswitch" ) ){
+    if( ! ( mode & OPEN_MODE_NOSWITCH ) ){
         switch_admin();
         set_current_page( m_notebook->page_num( *view ) );
     }
 
     // ロック
-    if( command.arg3 == "lock" ) lock( m_notebook->page_num( *view ) );
+    if( mode & OPEN_MODE_LOCK ) lock( m_notebook->page_num( *view ) );
 }
 
 
@@ -1040,17 +1086,38 @@ void Admin::switch_view( const std::string& url )
 //
 // タブ左移動
 //
-void Admin::tab_left()
+// updated == true の時は更新されたタブに移動
+//
+void Admin::tab_left( const bool updated )
 {
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages == 1 ) return;
 
     int page = m_notebook->get_current_page();
     if( page == -1 ) return;
 
-    if( page == 0 ) page = pages;
+#ifdef _DEBUG
+    std::cout << "Admin::tab_left updated << " << updated << " page = " << page;
+#endif
 
-    set_current_page( --page );
+    for( int i = 0; i < pages ; ++i ){
+
+        --page;
+        if( page < 0 ) page = pages -1;
+        if( ! updated ) break;
+
+        SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+        if( ! view ) return;
+
+        // updated アイコンが表示されているタブを見つける
+        if( get_notebook()->get_tabicon( page ) == view->get_icon( "updated" ) ) break;
+    }
+
+#ifdef _DEBUG
+    std::cout << " -> " << page << std::endl;
+#endif
+
+    if( page != m_notebook->get_current_page() ) set_current_page( page );
 }
 
 
@@ -1058,7 +1125,9 @@ void Admin::tab_left()
 //
 // タブ右移動
 //
-void Admin::tab_right()
+// updated == true の時は更新されたタブに移動
+//
+void Admin::tab_right( const bool updated )
 {
     int pages = m_notebook->get_n_pages();
     if( pages == 1 ) return;
@@ -1066,12 +1135,51 @@ void Admin::tab_right()
     int page = m_notebook->get_current_page();
     if( page == -1 ) return;
 
-    if( page == pages -1 ) page = -1;
+#ifdef _DEBUG
+    std::cout << "Admin::tab_right updated << " << updated << " page = " << page;
+#endif
 
-    set_current_page( ++page );
+    for( int i = 0; i < pages; ++i ){
+
+        ++page;
+        if( page >= pages ) page = 0;
+        if( ! updated ) break;
+
+        SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
+        if( ! view ) return;
+
+        // updated アイコンが表示されているタブを見つける
+        if( get_notebook()->get_tabicon( page ) == view->get_icon( "updated" ) ) break;
+    }
+
+#ifdef _DEBUG
+    std::cout << " -> " << page << std::endl;
+#endif
+
+    if( page != m_notebook->get_current_page() ) set_current_page( page );
 }
 
 
+//
+// タブ位置(1-9)で移動
+//
+void Admin::tab_num( const std::string& str_num )
+{
+    if( str_num.empty() ) return;
+
+    const int num = strtol( str_num.c_str(), NULL, 10 );
+
+    // Firefoxの動作に合わせた
+    // 0 → 無視
+    // 8以下で存在する数より多い → 無視
+    // 9(存在しない) → 最後のタブ
+    if ( num < 1 || num > 9 ||
+         ( num < 9 && num > get_tab_nums() ) ) return;
+
+    // 9は存在しなくてもそのまま渡してしまう
+    set_current_page( num - 1 );
+}
+
 
 //
 // タブ先頭移動
@@ -1085,6 +1193,15 @@ void Admin::tab_head()
 }
 
 
+//
+// フォーカスしてタブ先頭移動
+//
+void Admin::tab_head_focus()
+{
+    if( ! m_focus ) switch_admin();
+    tab_head();
+}
+
 
 //
 // タブ最後に移動
@@ -1098,6 +1215,14 @@ void Admin::tab_tail()
 }
 
 
+//
+// タブ最後に移動
+//
+void Admin::tab_tail_focus()
+{
+    if( ! m_focus ) switch_admin();
+    tab_tail();
+}
 
 
 //
@@ -1534,25 +1659,29 @@ void Admin::toggle_icon( const std::string& url )
         // オートリロードモードでロード待ち
         else if( view->get_autoreload_mode() != AUTORELOAD_NOT ) iconname = "loading_stop";
 
-        // 更新可能
+        // 古い
+        else if( view->is_old() ) iconname = "old";
+
+        // 更新チェックして更新可能 ( 更新はしていない )
         else if( view->is_check_update() ) iconname = "update";
 
-        // 更新済み
+        // 更新済み ( HTTP_OK 又は HTTP_PARTIAL_CONTENT )
         else if( view->is_updated() ){
 
             // タブがアクティブの時は通常アイコンを表示
             if( get_notebook()->page_num( *view ) == get_notebook()->get_current_page() ) iconname = "default";
+
             else iconname = "updated";
         }
 
-        // 古い
-        else if( view->is_old() ) iconname = "old";
-
 #ifdef _DEBUG
         std::cout << "name = " << iconname << std::endl;
 #endif
-        int id = view->get_icon( iconname );
+        const int id = view->get_icon( iconname );
         get_notebook()->set_tabicon( iconname, get_notebook()->page_num( *view ), id );
+
+        if( m_move_menu ) m_move_menu->update_icons();
+        if( m_tabswitchmenu ) m_tabswitchmenu->update_icons();
     }
 }
 
@@ -1673,12 +1802,21 @@ View* Admin::get_current_view()
 //
 // 指定したページに表示切替え
 //
-void Admin::set_current_page( int page )
+void Admin::set_current_page( const int page )
 {
     m_notebook->set_current_page( page );
 }
 
 
+//
+// フォーカスしてから指定したページに表示切替え
+//
+void Admin::set_current_page_focus( const int page )
+{
+    if( ! m_focus ) switch_admin();
+    m_notebook->set_current_page( page );
+}
+
 
 //
 // 現在表示されているページ番号
@@ -1692,7 +1830,7 @@ int Admin::get_current_page()
 //
 // 現在表示されているページのURL
 //
-std::string Admin::get_current_url()
+const std::string Admin::get_current_url()
 {
     SKELETON::View* view = get_current_view();
     if( ! view ) return std::string();
@@ -1736,22 +1874,33 @@ void Admin::slot_switch_page( GtkNotebookPage*, guint page )
 
 
 //
-// タブをクリック
+// タブをクリックした
 //
-void Admin::slot_tab_click( int page )
+void Admin::slot_tab_clicked( const int page )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::slot_tab_click " << page << std::endl;
+    std::cout << "Admin::slot_tab_clicked " << page << std::endl;
 #endif
 
-    set_current_page( page );
+    if( ! m_focus ) switch_admin();
+}
+
+
+// タブの上でホイールを回した
+void Admin::slot_tab_scrolled( GdkEventScroll* event )
+{
+#ifdef _DEBUG
+    std::cout << "Admin::slot_tab_scrolled\n";
+#endif
+
+    if( ! m_focus ) switch_admin();
 }
 
 
 //
 // タブを閉じる
 //
-void Admin::slot_tab_close( int page )
+void Admin::slot_tab_close( const int page )
 {
 #ifdef _DEBUG
     std::cout << "Admin::slot_tab_close " << page << std::endl;
@@ -1766,7 +1915,7 @@ void Admin::slot_tab_close( int page )
 //
 // タブ再読み込み
 //
-void Admin::slot_tab_reload( int page )
+void Admin::slot_tab_reload( const int page )
 {
 #ifdef _DEBUG
     std::cout << "Admin::slot_tab_reload " << page << std::endl;
@@ -1831,41 +1980,62 @@ void Admin::slot_tab_menu( int page, int x, int y )
     m_clicked_page = page;
 
     Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( m_ui_manager->get_widget( "/popup_menu" ) );
-    if( popupmenu ){
+    if( popupmenu && m_move_menu ){
 
-        // menu item をサブメニューから取り除く
-        for( int i = 0; i < MAX_TABS ; ++i ){
-            if( m_vec_movemenu_append[ i ] )m_move_menu->remove( *m_vec_movemenu_items[ i ] );
-            m_vec_movemenu_append[ i ] = false;
-        }
+        m_move_menu->remove_items();
+        m_move_menu->append_items();
+        m_move_menu->update_labels();
+        m_move_menu->update_icons();
 
-        // 移動サブメニューにタブ名をセットする
-        int pages = m_notebook->get_n_pages();
-        for( int i = 0; i < MIN( pages, MAX_TABS ); ++ i ){
-
-            Gtk::Label* label = dynamic_cast< Gtk::Label* >( m_vec_movemenu_items[ i ]->get_child() );
-            if( label ){
-
-                std::string name = m_notebook->get_tab_fulltext( i );
-                if( name.empty() ) name = "???";
-                const unsigned int maxsize = 50;
-                label->set_text( MISC::cut_str( name, maxsize ) );
-            }
-            m_move_menu->append( *m_vec_movemenu_items[ i ] );
-            m_vec_movemenu_append[ i ] = true;
-        }
-
-        // コメント更新
-        Gtk::Label* label = dynamic_cast< Gtk::Label* >( m_vec_movemenu_items[ MAX_TABS ]->get_child() );
-        if( label ) label->set_text_with_mnemonic( "移動 [ タブ数 " + MISC::itostr( pages ) +" ](_M)" );
-
-        m_move_menu->show_all();
+        Gtk::Label* label = dynamic_cast< Gtk::Label* >( m_move_menuitem->get_child() );
+        if( label ) label->set_text_with_mnemonic( ITEM_NAME_GO + std::string( " [ タブ数 " )
+                                                   + MISC::itostr( m_notebook->get_n_pages() ) +" ](_M)" );
 
         popupmenu->popup( 0, gtk_get_current_event_time() );
     }
 }
 
 
+// タブ切り替えメニュー表示
+void Admin::slot_show_tabswitchmenu()
+{
+#ifdef _DEBUG
+    std::cout << "Admin::slot_show_tabswitchmenu\n";
+#endif
+
+    if( ! m_tabswitchmenu ) m_tabswitchmenu = new SKELETON::TabSwitchMenu( m_notebook, this );
+
+    m_tabswitchmenu->remove_items();
+    m_tabswitchmenu->append_items();
+    m_tabswitchmenu->update_labels();
+    m_tabswitchmenu->update_icons();
+
+    m_tabswitchmenu->popup( Gtk::Menu::SlotPositionCalc( sigc::mem_fun( *this, &Admin::slot_popup_pos ) ),
+                            0, gtk_get_current_event_time() );
+}
+
+
+// タブ切り替えメニューの位置決め
+void Admin::slot_popup_pos( int& x, int& y, bool& push_in )
+{
+    if( ! m_tabswitchmenu ) return;
+    if( ! m_notebook ) return;
+
+    const int mrg = 16;
+
+    m_notebook->get_tabswitch_button().get_pointer( x, y );
+
+    int ox, oy;
+    m_notebook->get_tabswitch_button().get_window()->get_origin( ox, oy );
+    const Gdk::Rectangle rect = m_notebook->get_tabswitch_button().get_allocation();
+
+    x += ox + rect.get_x() - mrg;
+    y = oy + rect.get_y() + rect.get_height();
+
+    push_in = false;
+}
+
+
 //
 // 右クリックメニューの閉じる
 //
@@ -1973,9 +2143,9 @@ void Admin::slot_close_all_tabs()
 //
 void Admin::slot_check_update_all_tabs()
 {
-    check_update_all_tabs( m_clicked_page );
+    check_update_all_tabs( m_clicked_page, false );
 
-    CORE::get_checkupdate_manager()->run( false );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1984,9 +2154,9 @@ void Admin::slot_check_update_all_tabs()
 //
 void Admin::slot_check_update_reload_all_tabs()
 {
-    check_update_all_tabs( m_clicked_page );
+    check_update_all_tabs( m_clicked_page, true );
 
-    CORE::get_checkupdate_manager()->run( true );
+    CORE::get_checkupdate_manager()->run();
 }
 
 
@@ -1995,7 +2165,7 @@ void Admin::slot_check_update_reload_all_tabs()
 //
 // この後で CORE::get_checkupdate_manager()->run() すること
 //
-void Admin::check_update_all_tabs( const int from_page )
+void Admin::check_update_all_tabs( const int from_page, const bool open )
 {
 #ifdef _DEBUG
     std::cout << "Admin::check_update_all_tabs from = " << from_page << std::endl;
@@ -2008,13 +2178,13 @@ void Admin::check_update_all_tabs( const int from_page )
     // クリックしたタブから右側
     for( int i = from_page ; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
 
     // クリックしたタブから左側
     for( int i = 0 ; i < from_page; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
-        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url() );
+        if( view && view->get_enable_autoreload() ) CORE::get_checkupdate_manager()->push_back( view->get_url(), open );
     }
 }
 
@@ -2204,7 +2374,7 @@ void Admin::back_clicked_viewhistory( const int count )
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( ! view ) return;
     
-    m_notebook->set_current_page( m_clicked_page );
+    set_current_page( m_clicked_page );
     back_forward_viewhistory( view->get_url(), true, count );
 }
 
@@ -2225,7 +2395,7 @@ void Admin::forward_clicked_viewhistory( const int count )
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( ! view ) return;
 
-    m_notebook->set_current_page( m_clicked_page );
+    set_current_page( m_clicked_page );
     back_forward_viewhistory( view->get_url(), false, count );
 }
 
