@@ -326,6 +326,7 @@ const Gtk::TreePath EditTreeView::create_newdir( const Gtk::TreePath& path )
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_DIR;
+    info.parent = NULL;
     info.url = std::string();
     info.name = "新規ディレクトリ";
     info.data = std::string();
@@ -355,6 +356,7 @@ const Gtk::TreePath EditTreeView::create_newcomment( const Gtk::TreePath& path )
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_COMMENT;
+    info.parent = NULL;
     info.url = std::string();
     info.name = "コメント";
     info.data = std::string();
@@ -815,7 +817,7 @@ CORE::DATA_INFO_LIST EditTreeView::append_info( const CORE::DATA_INFO_LIST& list
 //
 // pathをまとめて削除
 //
-// force = true なら m_editable が false でも追加
+// force = true なら m_editable が false でも削除
 //
 void EditTreeView::delete_path( std::list< Gtk::TreePath >& list_path, const bool force )
 {
@@ -1209,6 +1211,8 @@ void EditTreeView::path2info( CORE::DATA_INFO& info, const Gtk::TreePath& path )
 
     info.type = row[ m_columns.m_type ];
 
+    info.parent = NULL;
+
     tmp_str = row[ m_columns.m_url ];
     info.url = tmp_str.raw();
 
@@ -1265,14 +1269,25 @@ const Gtk::TreePath EditTreeView::append_one_row( const std::string& url, const
     // 後ろに追加
     else row_new = *( treestore->insert_after( row_dest ) );
 
-    // スレの時は状態を最新にする
-    if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
+    // スレ一覧の状態を最新にする
+    std::string url_new = url;
+    if( type == TYPE_BOARD ){
 
-        if( DBTREE::article_status( url ) & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
-        if( DBTREE::article_status( url ) & STATUS_OLD ) type = TYPE_THREAD_OLD;
+        url_new = DBTREE::url_boardbase( url );
+
+        if( DBTREE::board_status( url_new ) & STATUS_UPDATE ) type = TYPE_BOARD_UPDATE;
     }
 
-    m_columns.setup_row( row_new, url, name, data, type );
+    // スレ状態を最新にする
+    if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
+
+        url_new = DBTREE::url_dat( url );
+
+        if( DBTREE::article_status( url_new ) & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
+        if( DBTREE::article_status( url_new ) & STATUS_OLD ) type = TYPE_THREAD_OLD;
+    }
+
+    m_columns.setup_row( row_new, url_new, name, data, type );
 
     return treestore->get_path( row_new );
 }
