@@ -21,9 +21,10 @@
 
 #include "config/globalconf.h"
 
+#include "control/controlutil.h"
+#include "control/controlid.h"
+
 #include "command.h"
-#include "controlutil.h"
-#include "controlid.h"
 
 #include <gtk/gtk.h>  // gtk_separator_tool_item_set_draw
 #include <gtk/gtkbutton.h>
@@ -35,7 +36,8 @@ using namespace SKELETON;
 ToolBar::ToolBar( Admin* admin )
     : m_admin( admin ),
       m_enable_slot( true ),
-      m_toolbar_shown( false ),
+      m_buttonbar_shown( false ),
+      m_buttonbar_packed( false ),
 
       m_tool_label( NULL ),
       m_ebox_label( NULL ),
@@ -43,6 +45,7 @@ ToolBar::ToolBar( Admin* admin )
 
       m_searchbar( NULL ),
       m_searchbar_shown( false ),
+      m_searchbar_packed( false ),
       m_button_open_searchbar( NULL ),
       m_button_close_searchbar( NULL ),
       m_button_up_search( NULL ),
@@ -60,6 +63,8 @@ ToolBar::ToolBar( Admin* admin )
       m_button_close( NULL ),
       m_button_delete( NULL ),
       m_button_favorite( NULL ),
+      m_button_undo( NULL ),
+      m_button_redo( NULL ),
       m_button_lock( NULL ),
 
       m_button_back( NULL ),
@@ -82,7 +87,15 @@ void ToolBar::set_url( const std::string& url )
 }
 
 
+const bool ToolBar::is_empty()
+{
+    return ( ! m_buttonbar.get_children().size() );
+}
+
+
+//
 // タブが切り替わった時にDragableNoteBook::set_current_toolbar()から呼び出される( Viewの情報を取得する )
+//
 // virtual
 void ToolBar::set_view( SKELETON::View* view )
 {
@@ -107,6 +120,8 @@ void ToolBar::set_view( SKELETON::View* view )
         if( m_button_lock ) m_button_lock->set_active( view->is_locked() );
     }
 
+    if( m_button_write ) m_button_write->set_sensitive( view->is_writeable() );
+
     if( m_entry_search ) m_entry_search->set_text( view->get_search_query() );
 
     if( m_label_board ) m_label_board->set_text( DBTREE::board_name( get_url() ) );
@@ -115,37 +130,61 @@ void ToolBar::set_view( SKELETON::View* view )
 }
 
 
-bool ToolBar::is_empty()
-{
-    return ( ! m_buttonbar.get_children().size() );
-}
-
-
-// ツールバーを表示
+//
+// タブが切り替わった時にDragableNoteBookから呼び出される( ツールバーを表示する )
+//
+// gtk+-2.4 辺りの古い gtk では、スレビューなどツールバーの複数が複数ある場合に
+// 最初からボタンバーを pack するとボタンが押せなくなる症状があったので、実際に
+// ツールバーが表示されるまでpackしないようにした
+//
 void ToolBar::show_toolbar()
 {
-    if( ! m_toolbar_shown ){
-
-        if( m_searchbar && m_searchbar_shown ) remove( *m_searchbar );
+    // ボタンバーのpack
+    if( m_buttonbar_shown && ! m_buttonbar_packed ){
 
+        if( m_searchbar_packed ) remove( *m_searchbar );
         pack_start( m_buttonbar, Gtk::PACK_SHRINK );
-        if( m_searchbar && m_searchbar_shown ) pack_start( *m_searchbar, Gtk::PACK_SHRINK );
+        if( m_searchbar_packed ) pack_start( *m_searchbar, Gtk::PACK_SHRINK );
 
         show_all_children();
         set_relief();
-        m_toolbar_shown = true;
+
+        m_buttonbar_packed = true;
+    }
+
+    // 検索バーのpack
+    if( m_searchbar_shown && ! m_searchbar_packed ){
+
+        pack_start( *m_searchbar, Gtk::PACK_SHRINK );
+
+        show_all_children();
+        set_relief();
+
+        m_searchbar_packed = true;
     }
 }
 
 
-// ツールバーを隠す
-void ToolBar::hide_toolbar()
+// ボタンバー表示
+void ToolBar::open_buttonbar()
 {
-    if( m_toolbar_shown ){
+    // フラグだけ立てて実際に pack するのは show_toolbar() の中
+    // 何故そんな面倒な事をしているかは show_toolbar() の説明を参照
+    m_buttonbar_shown = true;
+}
+
+
+// ボタンバーを隠す
+void ToolBar::close_buttonbar()
+{
+    m_buttonbar_shown = false;
+
+    if( m_buttonbar_packed ){
 
         remove( m_buttonbar );
+
         show_all_children();
-        m_toolbar_shown = false;
+        m_buttonbar_packed = false;
     }
 }
 
@@ -156,8 +195,7 @@ void ToolBar::update_button()
     unpack_buttons();
     pack_buttons();
 
-    if( m_buttonbar.get_children().size() ) show_toolbar();
-    else hide_toolbar();
+    if( ! m_buttonbar_shown ) close_buttonbar();
 
     // 進む、戻るボタンのsensitive状態を更新する
     set_url( m_url );
@@ -175,6 +213,18 @@ void ToolBar::unpack_buttons()
     }
 }
 
+// 検索ツールバー上のボタンのアンパック
+void ToolBar::unpack_search_buttons()
+{
+    if( ! m_searchbar ) return;
+
+    std::list< Gtk::Widget* > lists = m_searchbar->get_children();
+    std::list< Gtk::Widget* >::iterator it = lists.begin();
+    for( ; it != lists.end(); ++it ){
+        m_searchbar->remove( *(*it) );
+        if( dynamic_cast< Gtk::SeparatorToolItem* >( *it ) ) delete *it;
+    }
+}
 
 // ボタンのrelief指定
 void ToolBar::set_relief()
@@ -335,12 +385,9 @@ void ToolBar::open_searchbar()
     std::cout << "ToolBar::open_searchbar\n";
 #endif
 
-    if( ! m_searchbar_shown ){
-        pack_start( *m_searchbar, Gtk::PACK_SHRINK );
-        show_all_children();
-        m_searchbar_shown = true;
-        set_relief();
-    }
+    // フラグだけ立てて実際に pack するのは show_toolbar() の中
+    // 何故そんな面倒な事をしているかは show_toolbar() の説明を参照
+    m_searchbar_shown = true;
 }
 
 
@@ -353,10 +400,15 @@ void ToolBar::close_searchbar()
     std::cout << "ToolBar::close_searchbar\n";
 #endif
 
-    if( m_searchbar_shown ){
+    m_searchbar_shown = false;
+
+    if( m_searchbar_packed ){
+
         remove( *m_searchbar );
+
         show_all_children();
-        m_searchbar_shown = false;
+        m_searchbar_packed = false;
+
         m_admin->set_command( "focus_current_view" );
     }
 }
@@ -371,7 +423,7 @@ Gtk::ToolItem* ToolBar::get_button_open_searchbar()
     if( ! m_button_open_searchbar ){
         m_button_open_searchbar = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::FIND ) );
 
-        std::string tooltip = "検索バーを開く  " + CONTROL::get_motion( CONTROL::Search );
+        std::string tooltip = "検索バーを開く  " + CONTROL::get_str_motions( CONTROL::Search );
         set_tooltip( *m_button_open_searchbar, tooltip );
         m_button_open_searchbar->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_toggle_searchbar ) );
     }
@@ -383,7 +435,7 @@ Gtk::ToolItem* ToolBar::get_button_close_searchbar()
 {
     if( ! m_button_close_searchbar ){
         m_button_close_searchbar = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
-        set_tooltip( *m_button_close_searchbar, CONTROL::get_label_motion( CONTROL::CloseSearchBar ) );
+        set_tooltip( *m_button_close_searchbar, CONTROL::get_label_motions( CONTROL::CloseSearchBar ) );
         m_button_close_searchbar->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_toggle_searchbar ) );
     }
 
@@ -410,7 +462,7 @@ void ToolBar::slot_toggle_searchbar()
 //
 // 検索 entry
 //
-Gtk::ToolItem* ToolBar::get_entry_search( const int mode )
+Gtk::ToolItem* ToolBar::get_tool_search( const int mode )
 {
     if( ! m_tool_search ){
 
@@ -429,9 +481,15 @@ Gtk::ToolItem* ToolBar::get_entry_search( const int mode )
 }
 
 
-void ToolBar::add_search_mode( const int mode )
+SKELETON::CompletionEntry* ToolBar::get_entry_search()
 {
-    if( m_entry_search ) m_entry_search->add_mode( mode );
+    return m_entry_search;
+}
+
+
+void ToolBar::add_search_control_mode( const int mode )
+{
+    if( m_entry_search ) m_entry_search->add_control_mode( mode );
 }
 
 
@@ -471,7 +529,7 @@ void ToolBar::slot_active_search()
 }
 
 
-void ToolBar::slot_operate_search( int controlid )
+void ToolBar::slot_operate_search( const int controlid )
 {
     if( ! m_enable_slot ) return;
     if( m_url.empty() || ! m_admin ) return;
@@ -495,11 +553,11 @@ void ToolBar::focus_entry_search()
 //
 // 上検索
 //
-Gtk::ToolItem* ToolBar::get_button_up_search()
+Gtk::ToolButton* ToolBar::get_button_up_search()
 {
     if( ! m_button_up_search ){
         m_button_up_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_UP ) );
-        set_tooltip( *m_button_up_search, CONTROL::get_label_motion( CONTROL::SearchPrev ) );
+        set_tooltip( *m_button_up_search, CONTROL::get_label_motions( CONTROL::SearchPrev ) );
 
         m_button_up_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_up_search ) );
     }
@@ -524,11 +582,11 @@ void ToolBar::slot_clicked_up_search()
 //
 // 下検索
 //
-Gtk::ToolItem* ToolBar::get_button_down_search()
+Gtk::ToolButton* ToolBar::get_button_down_search()
 {
     if( ! m_button_down_search ){
         m_button_down_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_DOWN ) );
-        set_tooltip( *m_button_down_search, CONTROL::get_label_motion( CONTROL::SearchNext ) );
+        set_tooltip( *m_button_down_search, CONTROL::get_label_motions( CONTROL::SearchNext ) );
 
         m_button_down_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_down_search ) );
     }
@@ -567,7 +625,7 @@ Gtk::ToolItem* ToolBar::get_button_board()
         m_button_board->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_menu_board ) );
         m_button_board->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_open_board ) );
 
-        set_tooltip( *m_button_board, CONTROL::get_label_motion( CONTROL::OpenParentBoard ) );
+        set_tooltip( *m_button_board, CONTROL::get_label_motions( CONTROL::OpenParentBoard ) );
     }
 
     return m_button_board;
@@ -600,9 +658,10 @@ Gtk::ToolItem* ToolBar::get_button_write()
 {
     if( ! m_button_write ){
         m_button_write = Gtk::manage( new ImgToolButton( ICON::WRITE ) );
-        set_tooltip( *m_button_write, CONTROL::get_label_motion( CONTROL::WriteMessage ) );
+        set_tooltip( *m_button_write, CONTROL::get_label_motions( CONTROL::WriteMessage ) );
 
         m_button_write->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_write ) );
+        m_button_write->get_child()->signal_focus_out_event().connect( sigc::mem_fun(*this, &ToolBar::slot_focusout_write_button ) );
     }
 
     return m_button_write;
@@ -622,6 +681,44 @@ void ToolBar::slot_clicked_write()
 }
 
 
+// 書き込みボタンをフォーカス
+void ToolBar::focus_button_write()
+{
+    get_button_write()->get_child()->grab_focus();
+    drawframe_button_write( true );
+}
+
+
+// 書き込みボタンの廻りに枠を描く
+void ToolBar::drawframe_button_write( const bool draw )
+{
+    if( CONFIG::get_flat_button() ){
+
+        // relief が Gtk:: RELIEF_NONE のときにボタンに枠を描画
+        // gtk+-2.12.9/gtk/gtkbutton.c の gtk_button_enter_notify()
+        // とgtk_button_leave_notify() をハック
+        Gtk::Button* button = dynamic_cast< Gtk::Button* >( get_button_write()->get_child() );
+        if( button ){
+            GtkButton* gtkbutton = button->gobj();
+            gtkbutton->in_button = draw;
+            if( draw ) gtk_button_enter( gtkbutton );
+            else gtk_button_leave( gtkbutton );
+        }
+    }
+}
+
+
+bool ToolBar::slot_focusout_write_button( GdkEventFocus* event )
+{
+#ifdef _DEBUG
+    std::cout << "ToolBar::slot_focusout_write_button\n";
+#endif
+
+    drawframe_button_write( false );
+    return true;
+}
+
+
 //
 // 再読み込みボタン
 //
@@ -629,7 +726,7 @@ Gtk::ToolItem* ToolBar::get_button_reload()
 {
     if( ! m_button_reload ){
         m_button_reload = Gtk::manage( new ImgToolButton( Gtk::Stock::REFRESH ) );
-        set_tooltip( *m_button_reload, CONTROL::get_label_motion( CONTROL::Reload ) );
+        set_tooltip( *m_button_reload, CONTROL::get_label_motions( CONTROL::Reload ) );
 
         m_button_reload->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_reload ) );
     }
@@ -658,7 +755,7 @@ Gtk::ToolItem* ToolBar::get_button_stop()
 {
     if( ! m_button_stop ){
         m_button_stop = Gtk::manage( new ImgToolButton( Gtk::Stock::STOP ) );
-        set_tooltip( *m_button_stop, CONTROL::get_label_motion( CONTROL::StopLoading ) );
+        set_tooltip( *m_button_stop, CONTROL::get_label_motions( CONTROL::StopLoading ) );
 
         m_button_stop->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_stop ) );
     }
@@ -683,11 +780,11 @@ void ToolBar::slot_clicked_stop()
 //
 // 閉じるボタン
 //
-Gtk::ToolItem* ToolBar::get_button_close()
+Gtk::ToolButton* ToolBar::get_button_close()
 {
     if( ! m_button_close ){
         m_button_close = Gtk::manage( new ImgToolButton( Gtk::Stock::CLOSE ) );
-        set_tooltip( *m_button_close, CONTROL::get_label_motion( CONTROL::Quit ) );
+        set_tooltip( *m_button_close, CONTROL::get_label_motions( CONTROL::Quit ) );
 
         m_button_close->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_close ) );
     }
@@ -728,7 +825,7 @@ Gtk::ToolItem* ToolBar::get_button_delete()
 {
     if( ! m_button_delete ){
         m_button_delete = Gtk::manage( new ImgToolButton( Gtk::Stock::DELETE ) );
-        set_tooltip( *m_button_delete, CONTROL::get_label_motion( CONTROL::Delete ) );
+        set_tooltip( *m_button_delete, CONTROL::get_label_motions( CONTROL::Delete ) );
 
         m_button_delete->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_delete ) );
     }
@@ -757,7 +854,7 @@ Gtk::ToolItem* ToolBar::get_button_favorite()
 {
     if( ! m_button_favorite ){
         m_button_favorite = Gtk::manage( new ImgToolButton( Gtk::Stock::COPY ) );
-        set_tooltip( *m_button_favorite, CONTROL::get_label_motion( CONTROL::AppendFavorite ) );
+        set_tooltip( *m_button_favorite, CONTROL::get_label_motions( CONTROL::AppendFavorite ) );
 
         m_button_favorite->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_favorite ) );
     }
@@ -779,6 +876,36 @@ void ToolBar::slot_clicked_favorite()
 }
 
 
+//
+// UNDO ボタン
+//
+Gtk::ToolButton* ToolBar::get_button_undo()
+{
+    if( ! m_button_undo ){
+        m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
+        m_button_undo->set_sensitive( false );
+        set_tooltip( *m_button_undo, CONTROL::get_label_motions( CONTROL::Undo ) );
+    }
+
+    return m_button_undo;
+}
+
+
+//
+// REDO ボタン
+//
+Gtk::ToolButton* ToolBar::get_button_redo()
+{
+    if( ! m_button_redo ){
+        m_button_redo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::REDO ) );
+        m_button_redo->set_sensitive( false );
+        set_tooltip( *m_button_redo, CONTROL::get_label_motions( CONTROL::Redo ) );
+    }
+
+    return m_button_redo;
+}
+
+
 //
 // 戻るボタン
 //
@@ -790,7 +917,7 @@ Gtk::ToolItem* ToolBar::get_button_back()
         m_button_back->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_back ) );
         m_button_back->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_selected_back ) );
 
-        set_tooltip( *m_button_back, CONTROL::get_label_motion( CONTROL::PrevView ) );
+        set_tooltip( *m_button_back, CONTROL::get_label_motions( CONTROL::PrevView ) );
     }
 
     return m_button_back;
@@ -833,7 +960,7 @@ Gtk::ToolItem* ToolBar::get_button_forward()
         m_button_forward = Gtk::manage( new SKELETON::ToolBackForwardButton( "forward", false, m_url, false ) );
         m_button_forward->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_forward ) );
         m_button_forward->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_selected_forward ) );
-        set_tooltip( *m_button_forward, CONTROL::get_label_motion( CONTROL::NextView ) );
+        set_tooltip( *m_button_forward, CONTROL::get_label_motions( CONTROL::NextView ) );
     }
 
     return m_button_forward;
@@ -873,7 +1000,7 @@ Gtk::ToolItem* ToolBar::get_button_lock()
 {
     if( ! m_button_lock ){
         m_button_lock = Gtk::manage( new SKELETON::ImgToggleToolButton( Gtk::Stock::NO ) );
-        set_tooltip( *m_button_lock, CONTROL::get_label_motion( CONTROL::Lock ) );
+        set_tooltip( *m_button_lock, CONTROL::get_label_motions( CONTROL::Lock ) );
         m_button_lock->set_label( CONTROL::get_label( CONTROL::Lock ) );
         m_button_lock->signal_clicked().connect( sigc::mem_fun( *this, &ToolBar::slot_lock_clicked ) );
     }
