@@ -4,7 +4,7 @@
 #define _TYPE_H
 
 #include <string>
-#include <list>
+#include <vector>
 
 enum 
 {
@@ -37,19 +37,24 @@ enum
     TYPE_UNKNOWN
 };
 
+namespace Gtk
+{
+    class Window;
+}
 
 namespace CORE
 {
     struct DATA_INFO
     {
-        int type; 
+        int type;
+        Gtk::Window* parent;
         std::string url;
         std::string name;
         std::string path; // treeview の path
         std::string data;
     };
 
-    typedef std::list< CORE::DATA_INFO > DATA_INFO_LIST;
+    typedef std::vector< CORE::DATA_INFO > DATA_INFO_LIST;
 }
 
 #endif
